/********************************************************************************
** Form generated from reading UI file 'lxqttaskbarconfiguration.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LXQTTASKBARCONFIGURATION_H
#define UI_LXQTTASKBARCONFIGURATION_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_LXQtTaskbarConfiguration
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *WLContentGB;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QCheckBox *limitByDesktopCB;
    QComboBox *showDesktopNumCB;
    QCheckBox *limitByScreenCB;
    QCheckBox *limitByMinimizedCB;
    QCheckBox *raiseOnCurrentDesktopCB;
    QCheckBox *middleClickCB;
    QCheckBox *cycleOnWheelScroll;
    QGroupBox *groupingGB;
    QVBoxLayout *verticalLayout_3;
    QCheckBox *showGroupOnHoverCB;
    QGroupBox *WLApperanceGB;
    QFormLayout *formLayout;
    QLabel *buttonStyleL;
    QComboBox *buttonStyleCB;
    QLabel *buttonWidthL;
    QSpinBox *buttonWidthSB;
    QLabel *buttonHeightL;
    QSpinBox *buttonHeightSB;
    QCheckBox *autoRotateCB;
    QCheckBox *iconByClassCB;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttons;

    void setupUi(QDialog *LXQtTaskbarConfiguration)
    {
        if (LXQtTaskbarConfiguration->objectName().isEmpty())
            LXQtTaskbarConfiguration->setObjectName(QStringLiteral("LXQtTaskbarConfiguration"));
        LXQtTaskbarConfiguration->resize(401, 512);
        verticalLayout = new QVBoxLayout(LXQtTaskbarConfiguration);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        WLContentGB = new QGroupBox(LXQtTaskbarConfiguration);
        WLContentGB->setObjectName(QStringLiteral("WLContentGB"));
        verticalLayout_2 = new QVBoxLayout(WLContentGB);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(0);
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        limitByDesktopCB = new QCheckBox(WLContentGB);
        limitByDesktopCB->setObjectName(QStringLiteral("limitByDesktopCB"));

        horizontalLayout->addWidget(limitByDesktopCB);

        showDesktopNumCB = new QComboBox(WLContentGB);
        showDesktopNumCB->setObjectName(QStringLiteral("showDesktopNumCB"));

        horizontalLayout->addWidget(showDesktopNumCB);


        verticalLayout_2->addLayout(horizontalLayout);

        limitByScreenCB = new QCheckBox(WLContentGB);
        limitByScreenCB->setObjectName(QStringLiteral("limitByScreenCB"));

        verticalLayout_2->addWidget(limitByScreenCB);

        limitByMinimizedCB = new QCheckBox(WLContentGB);
        limitByMinimizedCB->setObjectName(QStringLiteral("limitByMinimizedCB"));

        verticalLayout_2->addWidget(limitByMinimizedCB);

        raiseOnCurrentDesktopCB = new QCheckBox(WLContentGB);
        raiseOnCurrentDesktopCB->setObjectName(QStringLiteral("raiseOnCurrentDesktopCB"));

        verticalLayout_2->addWidget(raiseOnCurrentDesktopCB);

        middleClickCB = new QCheckBox(WLContentGB);
        middleClickCB->setObjectName(QStringLiteral("middleClickCB"));

        verticalLayout_2->addWidget(middleClickCB);

        cycleOnWheelScroll = new QCheckBox(WLContentGB);
        cycleOnWheelScroll->setObjectName(QStringLiteral("cycleOnWheelScroll"));

        verticalLayout_2->addWidget(cycleOnWheelScroll);


        verticalLayout->addWidget(WLContentGB);

        groupingGB = new QGroupBox(LXQtTaskbarConfiguration);
        groupingGB->setObjectName(QStringLiteral("groupingGB"));
        groupingGB->setCheckable(true);
        verticalLayout_3 = new QVBoxLayout(groupingGB);
        verticalLayout_3->setObjectName(QStringLiteral("verticalLayout_3"));
        showGroupOnHoverCB = new QCheckBox(groupingGB);
        showGroupOnHoverCB->setObjectName(QStringLiteral("showGroupOnHoverCB"));

        verticalLayout_3->addWidget(showGroupOnHoverCB);


        verticalLayout->addWidget(groupingGB);

        WLApperanceGB = new QGroupBox(LXQtTaskbarConfiguration);
        WLApperanceGB->setObjectName(QStringLiteral("WLApperanceGB"));
        formLayout = new QFormLayout(WLApperanceGB);
        formLayout->setObjectName(QStringLiteral("formLayout"));
        formLayout->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        buttonStyleL = new QLabel(WLApperanceGB);
        buttonStyleL->setObjectName(QStringLiteral("buttonStyleL"));

        formLayout->setWidget(0, QFormLayout::LabelRole, buttonStyleL);

        buttonStyleCB = new QComboBox(WLApperanceGB);
        buttonStyleCB->setObjectName(QStringLiteral("buttonStyleCB"));

        formLayout->setWidget(0, QFormLayout::FieldRole, buttonStyleCB);

        buttonWidthL = new QLabel(WLApperanceGB);
        buttonWidthL->setObjectName(QStringLiteral("buttonWidthL"));

        formLayout->setWidget(1, QFormLayout::LabelRole, buttonWidthL);

        buttonWidthSB = new QSpinBox(WLApperanceGB);
        buttonWidthSB->setObjectName(QStringLiteral("buttonWidthSB"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(buttonWidthSB->sizePolicy().hasHeightForWidth());
        buttonWidthSB->setSizePolicy(sizePolicy);
        buttonWidthSB->setMinimum(1);
        buttonWidthSB->setMaximum(2147483647);

        formLayout->setWidget(1, QFormLayout::FieldRole, buttonWidthSB);

        buttonHeightL = new QLabel(WLApperanceGB);
        buttonHeightL->setObjectName(QStringLiteral("buttonHeightL"));

        formLayout->setWidget(2, QFormLayout::LabelRole, buttonHeightL);

        buttonHeightSB = new QSpinBox(WLApperanceGB);
        buttonHeightSB->setObjectName(QStringLiteral("buttonHeightSB"));
        sizePolicy.setHeightForWidth(buttonHeightSB->sizePolicy().hasHeightForWidth());
        buttonHeightSB->setSizePolicy(sizePolicy);
        buttonHeightSB->setMinimum(1);
        buttonHeightSB->setMaximum(500);

        formLayout->setWidget(2, QFormLayout::FieldRole, buttonHeightSB);

        autoRotateCB = new QCheckBox(WLApperanceGB);
        autoRotateCB->setObjectName(QStringLiteral("autoRotateCB"));

        formLayout->setWidget(3, QFormLayout::SpanningRole, autoRotateCB);

        iconByClassCB = new QCheckBox(WLApperanceGB);
        iconByClassCB->setObjectName(QStringLiteral("iconByClassCB"));

        formLayout->setWidget(4, QFormLayout::SpanningRole, iconByClassCB);


        verticalLayout->addWidget(WLApperanceGB);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttons = new QDialogButtonBox(LXQtTaskbarConfiguration);
        buttons->setObjectName(QStringLiteral("buttons"));
        buttons->setOrientation(Qt::Horizontal);
        buttons->setStandardButtons(QDialogButtonBox::Close|QDialogButtonBox::Reset);

        verticalLayout->addWidget(buttons);


        retranslateUi(LXQtTaskbarConfiguration);
        QObject::connect(buttons, SIGNAL(accepted()), LXQtTaskbarConfiguration, SLOT(accept()));
        QObject::connect(buttons, SIGNAL(rejected()), LXQtTaskbarConfiguration, SLOT(reject()));

        QMetaObject::connectSlotsByName(LXQtTaskbarConfiguration);
    } // setupUi

    void retranslateUi(QDialog *LXQtTaskbarConfiguration)
    {
        LXQtTaskbarConfiguration->setWindowTitle(QApplication::translate("LXQtTaskbarConfiguration", "Task Manager Settings", Q_NULLPTR));
        WLContentGB->setTitle(QApplication::translate("LXQtTaskbarConfiguration", "General", Q_NULLPTR));
        limitByDesktopCB->setText(QApplication::translate("LXQtTaskbarConfiguration", "Show only windows from desktop", Q_NULLPTR));
        limitByScreenCB->setText(QApplication::translate("LXQtTaskbarConfiguration", "Show only windows from &panel's screen", Q_NULLPTR));
        limitByMinimizedCB->setText(QApplication::translate("LXQtTaskbarConfiguration", "Show only minimized windows", Q_NULLPTR));
        raiseOnCurrentDesktopCB->setText(QApplication::translate("LXQtTaskbarConfiguration", "Raise minimized windows on current desktop", Q_NULLPTR));
        middleClickCB->setText(QApplication::translate("LXQtTaskbarConfiguration", "Close on middle-click", Q_NULLPTR));
        cycleOnWheelScroll->setText(QApplication::translate("LXQtTaskbarConfiguration", "Cycle windows on wheel scrolling", Q_NULLPTR));
        groupingGB->setTitle(QApplication::translate("LXQtTaskbarConfiguration", "Window &grouping", Q_NULLPTR));
        showGroupOnHoverCB->setText(QApplication::translate("LXQtTaskbarConfiguration", "Show popup on mouse hover", Q_NULLPTR));
        WLApperanceGB->setTitle(QApplication::translate("LXQtTaskbarConfiguration", "Appearance", Q_NULLPTR));
        buttonStyleL->setText(QApplication::translate("LXQtTaskbarConfiguration", "Button style", Q_NULLPTR));
        buttonWidthL->setText(QApplication::translate("LXQtTaskbarConfiguration", "Maximum button width", Q_NULLPTR));
        buttonWidthSB->setSuffix(QApplication::translate("LXQtTaskbarConfiguration", " px", Q_NULLPTR));
        buttonHeightL->setText(QApplication::translate("LXQtTaskbarConfiguration", "Maximum button height", Q_NULLPTR));
        buttonHeightSB->setSuffix(QApplication::translate("LXQtTaskbarConfiguration", " px", Q_NULLPTR));
        autoRotateCB->setText(QApplication::translate("LXQtTaskbarConfiguration", "Auto&rotate buttons when the panel is vertical", Q_NULLPTR));
        iconByClassCB->setText(QApplication::translate("LXQtTaskbarConfiguration", "Use icons by WindowClass, if available", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class LXQtTaskbarConfiguration: public Ui_LXQtTaskbarConfiguration {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LXQTTASKBARCONFIGURATION_H
