/********************************************************************************
** Form generated from reading UI file 'spacerconfiguration.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SPACERCONFIGURATION_H
#define UI_SPACERCONFIGURATION_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpinBox>

QT_BEGIN_NAMESPACE

class Ui_SpacerConfiguration
{
public:
    QGridLayout *gridLayout;
    QLabel *labelSize;
    QSpinBox *sizeSB;
    QLabel *labelType;
    QComboBox *typeCB;
    QDialogButtonBox *buttons;

    void setupUi(QDialog *SpacerConfiguration)
    {
        if (SpacerConfiguration->objectName().isEmpty())
            SpacerConfiguration->setObjectName(QStringLiteral("SpacerConfiguration"));
        SpacerConfiguration->resize(0, 0);
        gridLayout = new QGridLayout(SpacerConfiguration);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        labelSize = new QLabel(SpacerConfiguration);
        labelSize->setObjectName(QStringLiteral("labelSize"));

        gridLayout->addWidget(labelSize, 0, 0, 1, 1);

        sizeSB = new QSpinBox(SpacerConfiguration);
        sizeSB->setObjectName(QStringLiteral("sizeSB"));
        sizeSB->setMinimum(4);
        sizeSB->setMaximum(2048);
        sizeSB->setValue(8);

        gridLayout->addWidget(sizeSB, 0, 1, 1, 1);

        labelType = new QLabel(SpacerConfiguration);
        labelType->setObjectName(QStringLiteral("labelType"));

        gridLayout->addWidget(labelType, 1, 0, 1, 1);

        typeCB = new QComboBox(SpacerConfiguration);
        typeCB->setObjectName(QStringLiteral("typeCB"));
        typeCB->setEditable(false);

        gridLayout->addWidget(typeCB, 1, 1, 1, 1);

        buttons = new QDialogButtonBox(SpacerConfiguration);
        buttons->setObjectName(QStringLiteral("buttons"));
        buttons->setOrientation(Qt::Horizontal);
        buttons->setStandardButtons(QDialogButtonBox::Close);

        gridLayout->addWidget(buttons, 2, 0, 1, 2);


        retranslateUi(SpacerConfiguration);
        QObject::connect(buttons, SIGNAL(clicked(QAbstractButton*)), SpacerConfiguration, SLOT(close()));

        QMetaObject::connectSlotsByName(SpacerConfiguration);
    } // setupUi

    void retranslateUi(QDialog *SpacerConfiguration)
    {
        SpacerConfiguration->setWindowTitle(QApplication::translate("SpacerConfiguration", "Spacer Settings", Q_NULLPTR));
        labelSize->setText(QApplication::translate("SpacerConfiguration", "Space width:", Q_NULLPTR));
        labelType->setText(QApplication::translate("SpacerConfiguration", "Space type:", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class SpacerConfiguration: public Ui_SpacerConfiguration {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SPACERCONFIGURATION_H
