/********************************************************************************
** Form generated from reading UI file 'lxqtworldclockconfigurationtimezones.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LXQTWORLDCLOCKCONFIGURATIONTIMEZONES_H
#define UI_LXQTWORLDCLOCKCONFIGURATIONTIMEZONES_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_LXQtWorldClockConfigurationTimeZones
{
public:
    QVBoxLayout *verticalLayout_3;
    QTreeWidget *timeZonesTW;
    QDialogButtonBox *buttons;

    void setupUi(QDialog *LXQtWorldClockConfigurationTimeZones)
    {
        if (LXQtWorldClockConfigurationTimeZones->objectName().isEmpty())
            LXQtWorldClockConfigurationTimeZones->setObjectName(QStringLiteral("LXQtWorldClockConfigurationTimeZones"));
        LXQtWorldClockConfigurationTimeZones->resize(718, 280);
        verticalLayout_3 = new QVBoxLayout(LXQtWorldClockConfigurationTimeZones);
        verticalLayout_3->setObjectName(QStringLiteral("verticalLayout_3"));
        timeZonesTW = new QTreeWidget(LXQtWorldClockConfigurationTimeZones);
        timeZonesTW->setObjectName(QStringLiteral("timeZonesTW"));
        timeZonesTW->setEditTriggers(QAbstractItemView::NoEditTriggers);
        timeZonesTW->setAlternatingRowColors(true);
        timeZonesTW->setSortingEnabled(true);
        timeZonesTW->setColumnCount(4);
        timeZonesTW->header()->setDefaultSectionSize(150);

        verticalLayout_3->addWidget(timeZonesTW);

        buttons = new QDialogButtonBox(LXQtWorldClockConfigurationTimeZones);
        buttons->setObjectName(QStringLiteral("buttons"));
        buttons->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_3->addWidget(buttons);

        QWidget::setTabOrder(timeZonesTW, buttons);

        retranslateUi(LXQtWorldClockConfigurationTimeZones);
        QObject::connect(buttons, SIGNAL(accepted()), LXQtWorldClockConfigurationTimeZones, SLOT(accept()));
        QObject::connect(buttons, SIGNAL(rejected()), LXQtWorldClockConfigurationTimeZones, SLOT(reject()));

        QMetaObject::connectSlotsByName(LXQtWorldClockConfigurationTimeZones);
    } // setupUi

    void retranslateUi(QDialog *LXQtWorldClockConfigurationTimeZones)
    {
        LXQtWorldClockConfigurationTimeZones->setWindowTitle(QApplication::translate("LXQtWorldClockConfigurationTimeZones", "World Clock Time Zones", Q_NULLPTR));
        QTreeWidgetItem *___qtreewidgetitem = timeZonesTW->headerItem();
        ___qtreewidgetitem->setText(3, QApplication::translate("LXQtWorldClockConfigurationTimeZones", "Country", Q_NULLPTR));
        ___qtreewidgetitem->setText(2, QApplication::translate("LXQtWorldClockConfigurationTimeZones", "Comment", Q_NULLPTR));
        ___qtreewidgetitem->setText(1, QApplication::translate("LXQtWorldClockConfigurationTimeZones", "Name", Q_NULLPTR));
        ___qtreewidgetitem->setText(0, QApplication::translate("LXQtWorldClockConfigurationTimeZones", "Time zone", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class LXQtWorldClockConfigurationTimeZones: public Ui_LXQtWorldClockConfigurationTimeZones {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LXQTWORLDCLOCKCONFIGURATIONTIMEZONES_H
