/********************************************************************************
** Form generated from reading UI file 'desktopswitchconfiguration.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DESKTOPSWITCHCONFIGURATION_H
#define UI_DESKTOPSWITCHCONFIGURATION_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_DesktopSwitchConfiguration
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QSpinBox *rowsSB;
    QLabel *labelButtons;
    QLabel *labelRowsSB;
    QComboBox *labelTypeCB;
    QGroupBox *namesGroupBox;
    QFormLayout *formLayout;
    QDialogButtonBox *buttons;

    void setupUi(QDialog *DesktopSwitchConfiguration)
    {
        if (DesktopSwitchConfiguration->objectName().isEmpty())
            DesktopSwitchConfiguration->setObjectName(QStringLiteral("DesktopSwitchConfiguration"));
        DesktopSwitchConfiguration->resize(213, 207);
        verticalLayout = new QVBoxLayout(DesktopSwitchConfiguration);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        groupBox = new QGroupBox(DesktopSwitchConfiguration);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        rowsSB = new QSpinBox(groupBox);
        rowsSB->setObjectName(QStringLiteral("rowsSB"));
        rowsSB->setMinimum(1);
        rowsSB->setMaximum(40);
        rowsSB->setValue(1);

        gridLayout->addWidget(rowsSB, 0, 2, 1, 1);

        labelButtons = new QLabel(groupBox);
        labelButtons->setObjectName(QStringLiteral("labelButtons"));

        gridLayout->addWidget(labelButtons, 1, 0, 1, 1);

        labelRowsSB = new QLabel(groupBox);
        labelRowsSB->setObjectName(QStringLiteral("labelRowsSB"));

        gridLayout->addWidget(labelRowsSB, 0, 0, 1, 1);

        labelTypeCB = new QComboBox(groupBox);
        labelTypeCB->setObjectName(QStringLiteral("labelTypeCB"));

        gridLayout->addWidget(labelTypeCB, 1, 2, 1, 1);


        verticalLayout->addWidget(groupBox);

        namesGroupBox = new QGroupBox(DesktopSwitchConfiguration);
        namesGroupBox->setObjectName(QStringLiteral("namesGroupBox"));
        formLayout = new QFormLayout(namesGroupBox);
        formLayout->setObjectName(QStringLiteral("formLayout"));

        verticalLayout->addWidget(namesGroupBox);

        buttons = new QDialogButtonBox(DesktopSwitchConfiguration);
        buttons->setObjectName(QStringLiteral("buttons"));
        buttons->setOrientation(Qt::Horizontal);
        buttons->setStandardButtons(QDialogButtonBox::Close);

        verticalLayout->addWidget(buttons);


        retranslateUi(DesktopSwitchConfiguration);

        QMetaObject::connectSlotsByName(DesktopSwitchConfiguration);
    } // setupUi

    void retranslateUi(QDialog *DesktopSwitchConfiguration)
    {
        DesktopSwitchConfiguration->setWindowTitle(QApplication::translate("DesktopSwitchConfiguration", "DesktopSwitch settings", Q_NULLPTR));
        groupBox->setTitle(QApplication::translate("DesktopSwitchConfiguration", "Appearance", Q_NULLPTR));
        labelButtons->setText(QApplication::translate("DesktopSwitchConfiguration", "Desktop labels:", Q_NULLPTR));
        labelRowsSB->setText(QApplication::translate("DesktopSwitchConfiguration", "Number of rows:", Q_NULLPTR));
        labelTypeCB->clear();
        labelTypeCB->insertItems(0, QStringList()
         << QApplication::translate("DesktopSwitchConfiguration", "Numbers", Q_NULLPTR)
         << QApplication::translate("DesktopSwitchConfiguration", "Names", Q_NULLPTR)
         << QApplication::translate("DesktopSwitchConfiguration", "None", Q_NULLPTR)
        );
        namesGroupBox->setTitle(QApplication::translate("DesktopSwitchConfiguration", "Desktop names", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class DesktopSwitchConfiguration: public Ui_DesktopSwitchConfiguration {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DESKTOPSWITCHCONFIGURATION_H
