/********************************************************************************
** Form generated from reading UI file 'lxqtmainmenuconfiguration.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LXQTMAINMENUCONFIGURATION_H
#define UI_LXQTMAINMENUCONFIGURATION_H

#include <LXQtGlobalKeysUi/ShortcutSelector>
#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_LXQtMainMenuConfiguration
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *generalGB;
    QGridLayout *gridLayout;
    QCheckBox *iconCB;
    QLineEdit *iconLE;
    QPushButton *iconPB;
    QCheckBox *showTextCB;
    QLineEdit *textLE;
    QCheckBox *customFontCB;
    QSpinBox *customFontSizeSB;
    QGroupBox *menuGB;
    QGridLayout *gridLayout_2;
    QLabel *menuFileL;
    QLineEdit *menuFilePathLE;
    QPushButton *chooseMenuFilePB;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_3;
    ShortcutSelector *shortcutEd;
    QLabel *label;
    QGroupBox *searchGB;
    QGridLayout *gridLayout_4;
    QLabel *filterShowMaxWidthL;
    QCheckBox *filterShowCB;
    QSpinBox *filterShowMaxItemsSB;
    QLabel *filterShowMaxItemsL;
    QCheckBox *filterMenuCB;
    QSpinBox *filterShowMaxWidthSB;
    QCheckBox *filterShowHideMenuCB;
    QCheckBox *filterClearCB;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttons;

    void setupUi(QDialog *LXQtMainMenuConfiguration)
    {
        if (LXQtMainMenuConfiguration->objectName().isEmpty())
            LXQtMainMenuConfiguration->setObjectName(QStringLiteral("LXQtMainMenuConfiguration"));
        LXQtMainMenuConfiguration->resize(481, 501);
        verticalLayout = new QVBoxLayout(LXQtMainMenuConfiguration);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        generalGB = new QGroupBox(LXQtMainMenuConfiguration);
        generalGB->setObjectName(QStringLiteral("generalGB"));
        generalGB->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        generalGB->setFlat(false);
        generalGB->setCheckable(false);
        gridLayout = new QGridLayout(generalGB);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        iconCB = new QCheckBox(generalGB);
        iconCB->setObjectName(QStringLiteral("iconCB"));

        gridLayout->addWidget(iconCB, 0, 0, 1, 1);

        iconLE = new QLineEdit(generalGB);
        iconLE->setObjectName(QStringLiteral("iconLE"));
        iconLE->setEnabled(false);

        gridLayout->addWidget(iconLE, 0, 1, 1, 1);

        iconPB = new QPushButton(generalGB);
        iconPB->setObjectName(QStringLiteral("iconPB"));
        iconPB->setEnabled(false);

        gridLayout->addWidget(iconPB, 0, 2, 1, 1);

        showTextCB = new QCheckBox(generalGB);
        showTextCB->setObjectName(QStringLiteral("showTextCB"));

        gridLayout->addWidget(showTextCB, 1, 0, 1, 1);

        textLE = new QLineEdit(generalGB);
        textLE->setObjectName(QStringLiteral("textLE"));
        textLE->setEnabled(false);

        gridLayout->addWidget(textLE, 1, 1, 1, 1);

        customFontCB = new QCheckBox(generalGB);
        customFontCB->setObjectName(QStringLiteral("customFontCB"));
        customFontCB->setEnabled(true);

        gridLayout->addWidget(customFontCB, 2, 0, 1, 1);

        customFontSizeSB = new QSpinBox(generalGB);
        customFontSizeSB->setObjectName(QStringLiteral("customFontSizeSB"));
        customFontSizeSB->setEnabled(false);
        customFontSizeSB->setMinimum(1);
        customFontSizeSB->setValue(11);

        gridLayout->addWidget(customFontSizeSB, 2, 1, 1, 1);


        verticalLayout->addWidget(generalGB);

        menuGB = new QGroupBox(LXQtMainMenuConfiguration);
        menuGB->setObjectName(QStringLiteral("menuGB"));
        menuGB->setEnabled(true);
        gridLayout_2 = new QGridLayout(menuGB);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        menuFileL = new QLabel(menuGB);
        menuFileL->setObjectName(QStringLiteral("menuFileL"));

        gridLayout_2->addWidget(menuFileL, 0, 0, 1, 1);

        menuFilePathLE = new QLineEdit(menuGB);
        menuFilePathLE->setObjectName(QStringLiteral("menuFilePathLE"));

        gridLayout_2->addWidget(menuFilePathLE, 0, 1, 1, 1);

        chooseMenuFilePB = new QPushButton(menuGB);
        chooseMenuFilePB->setObjectName(QStringLiteral("chooseMenuFilePB"));

        gridLayout_2->addWidget(chooseMenuFilePB, 0, 2, 1, 1);


        verticalLayout->addWidget(menuGB);

        groupBox = new QGroupBox(LXQtMainMenuConfiguration);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        gridLayout_3 = new QGridLayout(groupBox);
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        shortcutEd = new ShortcutSelector(groupBox);
        shortcutEd->setObjectName(QStringLiteral("shortcutEd"));
        shortcutEd->setMinimumSize(QSize(200, 0));

        gridLayout_3->addWidget(shortcutEd, 0, 1, 1, 1);

        label = new QLabel(groupBox);
        label->setObjectName(QStringLiteral("label"));

        gridLayout_3->addWidget(label, 0, 0, 1, 1);


        verticalLayout->addWidget(groupBox);

        searchGB = new QGroupBox(LXQtMainMenuConfiguration);
        searchGB->setObjectName(QStringLiteral("searchGB"));
        gridLayout_4 = new QGridLayout(searchGB);
        gridLayout_4->setObjectName(QStringLiteral("gridLayout_4"));
        filterShowMaxWidthL = new QLabel(searchGB);
        filterShowMaxWidthL->setObjectName(QStringLiteral("filterShowMaxWidthL"));

        gridLayout_4->addWidget(filterShowMaxWidthL, 2, 1, 1, 1);

        filterShowCB = new QCheckBox(searchGB);
        filterShowCB->setObjectName(QStringLiteral("filterShowCB"));

        gridLayout_4->addWidget(filterShowCB, 1, 0, 1, 1);

        filterShowMaxItemsSB = new QSpinBox(searchGB);
        filterShowMaxItemsSB->setObjectName(QStringLiteral("filterShowMaxItemsSB"));
        filterShowMaxItemsSB->setMaximum(20);

        gridLayout_4->addWidget(filterShowMaxItemsSB, 1, 2, 1, 1);

        filterShowMaxItemsL = new QLabel(searchGB);
        filterShowMaxItemsL->setObjectName(QStringLiteral("filterShowMaxItemsL"));

        gridLayout_4->addWidget(filterShowMaxItemsL, 1, 1, 1, 1);

        filterMenuCB = new QCheckBox(searchGB);
        filterMenuCB->setObjectName(QStringLiteral("filterMenuCB"));

        gridLayout_4->addWidget(filterMenuCB, 0, 0, 1, 3);

        filterShowMaxWidthSB = new QSpinBox(searchGB);
        filterShowMaxWidthSB->setObjectName(QStringLiteral("filterShowMaxWidthSB"));
        filterShowMaxWidthSB->setMinimum(40);
        filterShowMaxWidthSB->setMaximum(1000);

        gridLayout_4->addWidget(filterShowMaxWidthSB, 2, 2, 1, 1);

        filterShowHideMenuCB = new QCheckBox(searchGB);
        filterShowHideMenuCB->setObjectName(QStringLiteral("filterShowHideMenuCB"));

        gridLayout_4->addWidget(filterShowHideMenuCB, 3, 1, 1, 2);

        filterClearCB = new QCheckBox(searchGB);
        filterClearCB->setObjectName(QStringLiteral("filterClearCB"));

        gridLayout_4->addWidget(filterClearCB, 4, 0, 1, 3);


        verticalLayout->addWidget(searchGB);

        verticalSpacer = new QSpacerItem(20, 41, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttons = new QDialogButtonBox(LXQtMainMenuConfiguration);
        buttons->setObjectName(QStringLiteral("buttons"));
        buttons->setOrientation(Qt::Horizontal);
        buttons->setStandardButtons(QDialogButtonBox::Close|QDialogButtonBox::Reset);

        verticalLayout->addWidget(buttons);


        retranslateUi(LXQtMainMenuConfiguration);
        QObject::connect(customFontCB, SIGNAL(toggled(bool)), customFontSizeSB, SLOT(setEnabled(bool)));
        QObject::connect(showTextCB, SIGNAL(toggled(bool)), textLE, SLOT(setEnabled(bool)));
        QObject::connect(iconCB, SIGNAL(toggled(bool)), iconLE, SLOT(setEnabled(bool)));
        QObject::connect(iconCB, SIGNAL(toggled(bool)), iconPB, SLOT(setEnabled(bool)));
        QObject::connect(filterShowCB, SIGNAL(toggled(bool)), filterShowMaxItemsSB, SLOT(setEnabled(bool)));
        QObject::connect(filterShowCB, SIGNAL(toggled(bool)), filterShowMaxItemsL, SLOT(setEnabled(bool)));
        QObject::connect(filterShowCB, SIGNAL(toggled(bool)), filterShowMaxWidthSB, SLOT(setEnabled(bool)));
        QObject::connect(filterShowCB, SIGNAL(toggled(bool)), filterShowMaxWidthL, SLOT(setEnabled(bool)));
        QObject::connect(filterShowCB, SIGNAL(toggled(bool)), filterShowHideMenuCB, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(LXQtMainMenuConfiguration);
    } // setupUi

    void retranslateUi(QDialog *LXQtMainMenuConfiguration)
    {
        LXQtMainMenuConfiguration->setWindowTitle(QApplication::translate("LXQtMainMenuConfiguration", "Main Menu settings", Q_NULLPTR));
        generalGB->setTitle(QApplication::translate("LXQtMainMenuConfiguration", "General", Q_NULLPTR));
        iconCB->setText(QApplication::translate("LXQtMainMenuConfiguration", "Icon:", Q_NULLPTR));
        iconPB->setText(QString());
        showTextCB->setText(QApplication::translate("LXQtMainMenuConfiguration", "Button text:", Q_NULLPTR));
        customFontCB->setText(QApplication::translate("LXQtMainMenuConfiguration", "Custom font size:", Q_NULLPTR));
        customFontSizeSB->setSuffix(QApplication::translate("LXQtMainMenuConfiguration", " pt", Q_NULLPTR));
        menuGB->setTitle(QApplication::translate("LXQtMainMenuConfiguration", "Menu file", Q_NULLPTR));
        menuFileL->setText(QApplication::translate("LXQtMainMenuConfiguration", "Menu file:", Q_NULLPTR));
        groupBox->setTitle(QApplication::translate("LXQtMainMenuConfiguration", "Keyboard Shortcut", Q_NULLPTR));
        shortcutEd->setText(QString());
        label->setText(QApplication::translate("LXQtMainMenuConfiguration", "Click the button to record shortcut:", Q_NULLPTR));
        searchGB->setTitle(QApplication::translate("LXQtMainMenuConfiguration", "Search", Q_NULLPTR));
        filterShowMaxWidthL->setText(QApplication::translate("LXQtMainMenuConfiguration", "max. item width:", Q_NULLPTR));
        filterShowCB->setText(QApplication::translate("LXQtMainMenuConfiguration", "Show matching entries:", Q_NULLPTR));
        filterShowMaxItemsL->setText(QApplication::translate("LXQtMainMenuConfiguration", "Maximum visible items:", Q_NULLPTR));
        filterMenuCB->setText(QApplication::translate("LXQtMainMenuConfiguration", "Filter menu entries", Q_NULLPTR));
        filterShowMaxWidthSB->setSuffix(QApplication::translate("LXQtMainMenuConfiguration", " px", Q_NULLPTR));
        filterShowHideMenuCB->setText(QApplication::translate("LXQtMainMenuConfiguration", "Hide menu entries while searching", Q_NULLPTR));
        filterClearCB->setText(QApplication::translate("LXQtMainMenuConfiguration", "Clear search upon showing menu", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class LXQtMainMenuConfiguration: public Ui_LXQtMainMenuConfiguration {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LXQTMAINMENUCONFIGURATION_H
