/********************************************************************************
** Form generated from reading UI file 'lxqtcpuloadconfiguration.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LXQTCPULOADCONFIGURATION_H
#define UI_LXQTCPULOADCONFIGURATION_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>

QT_BEGIN_NAMESPACE

class Ui_LXQtCpuLoadConfiguration
{
public:
    QGridLayout *gridLayout_2;
    QGroupBox *generalGB;
    QGridLayout *gridLayout;
    QCheckBox *showTextCB;
    QLabel *label;
    QDoubleSpinBox *updateIntervalSpinBox;
    QLabel *barOrientationL;
    QComboBox *barOrientationCOB;
    QLabel *barWidthL;
    QSpinBox *barWidthSB;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttons;

    void setupUi(QDialog *LXQtCpuLoadConfiguration)
    {
        if (LXQtCpuLoadConfiguration->objectName().isEmpty())
            LXQtCpuLoadConfiguration->setObjectName(QStringLiteral("LXQtCpuLoadConfiguration"));
        LXQtCpuLoadConfiguration->resize(285, 191);
        gridLayout_2 = new QGridLayout(LXQtCpuLoadConfiguration);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        generalGB = new QGroupBox(LXQtCpuLoadConfiguration);
        generalGB->setObjectName(QStringLiteral("generalGB"));
        generalGB->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        generalGB->setFlat(false);
        generalGB->setCheckable(false);
        gridLayout = new QGridLayout(generalGB);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        showTextCB = new QCheckBox(generalGB);
        showTextCB->setObjectName(QStringLiteral("showTextCB"));

        gridLayout->addWidget(showTextCB, 0, 0, 1, 2);

        label = new QLabel(generalGB);
        label->setObjectName(QStringLiteral("label"));

        gridLayout->addWidget(label, 1, 0, 1, 1);

        updateIntervalSpinBox = new QDoubleSpinBox(generalGB);
        updateIntervalSpinBox->setObjectName(QStringLiteral("updateIntervalSpinBox"));
        updateIntervalSpinBox->setDecimals(1);
        updateIntervalSpinBox->setMinimum(0.5);
        updateIntervalSpinBox->setMaximum(10000);
        updateIntervalSpinBox->setSingleStep(0.5);
        updateIntervalSpinBox->setValue(1);

        gridLayout->addWidget(updateIntervalSpinBox, 1, 1, 1, 1);

        barOrientationL = new QLabel(generalGB);
        barOrientationL->setObjectName(QStringLiteral("barOrientationL"));

        gridLayout->addWidget(barOrientationL, 2, 0, 1, 1);

        barOrientationCOB = new QComboBox(generalGB);
        barOrientationCOB->setObjectName(QStringLiteral("barOrientationCOB"));

        gridLayout->addWidget(barOrientationCOB, 2, 1, 1, 1);

        barWidthL = new QLabel(generalGB);
        barWidthL->setObjectName(QStringLiteral("barWidthL"));

        gridLayout->addWidget(barWidthL, 3, 0, 1, 1);

        barWidthSB = new QSpinBox(generalGB);
        barWidthSB->setObjectName(QStringLiteral("barWidthSB"));
        barWidthSB->setMinimum(4);
        barWidthSB->setMaximum(2048);
        barWidthSB->setValue(20);

        gridLayout->addWidget(barWidthSB, 3, 1, 1, 1);


        gridLayout_2->addWidget(generalGB, 0, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 41, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 1, 0, 1, 1);

        buttons = new QDialogButtonBox(LXQtCpuLoadConfiguration);
        buttons->setObjectName(QStringLiteral("buttons"));
        buttons->setOrientation(Qt::Horizontal);
        buttons->setStandardButtons(QDialogButtonBox::Close|QDialogButtonBox::Reset);

        gridLayout_2->addWidget(buttons, 2, 0, 1, 1);


        retranslateUi(LXQtCpuLoadConfiguration);

        QMetaObject::connectSlotsByName(LXQtCpuLoadConfiguration);
    } // setupUi

    void retranslateUi(QDialog *LXQtCpuLoadConfiguration)
    {
        LXQtCpuLoadConfiguration->setWindowTitle(QApplication::translate("LXQtCpuLoadConfiguration", "CPU Load Settings", Q_NULLPTR));
        generalGB->setTitle(QApplication::translate("LXQtCpuLoadConfiguration", "General", Q_NULLPTR));
        showTextCB->setText(QApplication::translate("LXQtCpuLoadConfiguration", "Show text", Q_NULLPTR));
        label->setText(QApplication::translate("LXQtCpuLoadConfiguration", "Update interval:", Q_NULLPTR));
        updateIntervalSpinBox->setSuffix(QApplication::translate("LXQtCpuLoadConfiguration", "sec", Q_NULLPTR));
        barOrientationL->setText(QApplication::translate("LXQtCpuLoadConfiguration", "Bar orientation:", Q_NULLPTR));
        barWidthL->setText(QApplication::translate("LXQtCpuLoadConfiguration", "Bar width:", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class LXQtCpuLoadConfiguration: public Ui_LXQtCpuLoadConfiguration {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LXQTCPULOADCONFIGURATION_H
