/****************************************************************************
** Meta object code from reading C++ file 'lxqtpanel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/lxqt-panel-0.12.0/panel/lxqtpanel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'lxqtpanel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_LXQtPanel_t {
    QByteArrayData data[52];
    char stringdata0[593];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_LXQtPanel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_LXQtPanel_t qt_meta_stringdata_LXQtPanel = {
    {
QT_MOC_LITERAL(0, 0, 9), // "LXQtPanel"
QT_MOC_LITERAL(1, 10, 9), // "realigned"
QT_MOC_LITERAL(2, 20, 0), // ""
QT_MOC_LITERAL(3, 21, 13), // "deletedByUser"
QT_MOC_LITERAL(4, 35, 10), // "LXQtPanel*"
QT_MOC_LITERAL(5, 46, 4), // "self"
QT_MOC_LITERAL(6, 51, 11), // "pluginAdded"
QT_MOC_LITERAL(7, 63, 13), // "pluginRemoved"
QT_MOC_LITERAL(8, 77, 4), // "show"
QT_MOC_LITERAL(9, 82, 9), // "showPanel"
QT_MOC_LITERAL(10, 92, 7), // "animate"
QT_MOC_LITERAL(11, 100, 9), // "hidePanel"
QT_MOC_LITERAL(12, 110, 13), // "hidePanelWork"
QT_MOC_LITERAL(13, 124, 12), // "setPanelSize"
QT_MOC_LITERAL(14, 137, 5), // "value"
QT_MOC_LITERAL(15, 143, 4), // "save"
QT_MOC_LITERAL(16, 148, 11), // "setIconSize"
QT_MOC_LITERAL(17, 160, 12), // "setLineCount"
QT_MOC_LITERAL(18, 173, 9), // "setLength"
QT_MOC_LITERAL(19, 183, 6), // "length"
QT_MOC_LITERAL(20, 190, 10), // "inPercents"
QT_MOC_LITERAL(21, 201, 11), // "setPosition"
QT_MOC_LITERAL(22, 213, 6), // "screen"
QT_MOC_LITERAL(23, 220, 20), // "ILXQtPanel::Position"
QT_MOC_LITERAL(24, 241, 8), // "position"
QT_MOC_LITERAL(25, 250, 12), // "setAlignment"
QT_MOC_LITERAL(26, 263, 20), // "LXQtPanel::Alignment"
QT_MOC_LITERAL(27, 284, 12), // "setFontColor"
QT_MOC_LITERAL(28, 297, 5), // "color"
QT_MOC_LITERAL(29, 303, 18), // "setBackgroundColor"
QT_MOC_LITERAL(30, 322, 18), // "setBackgroundImage"
QT_MOC_LITERAL(31, 341, 4), // "path"
QT_MOC_LITERAL(32, 346, 10), // "setOpacity"
QT_MOC_LITERAL(33, 357, 7), // "opacity"
QT_MOC_LITERAL(34, 365, 15), // "setReserveSpace"
QT_MOC_LITERAL(35, 381, 12), // "reserveSpace"
QT_MOC_LITERAL(36, 394, 10), // "setHidable"
QT_MOC_LITERAL(37, 405, 7), // "hidable"
QT_MOC_LITERAL(38, 413, 16), // "setAnimationTime"
QT_MOC_LITERAL(39, 430, 13), // "animationTime"
QT_MOC_LITERAL(40, 444, 12), // "setShowDelay"
QT_MOC_LITERAL(41, 457, 9), // "showDelay"
QT_MOC_LITERAL(42, 467, 12), // "saveSettings"
QT_MOC_LITERAL(43, 480, 5), // "later"
QT_MOC_LITERAL(44, 486, 13), // "ensureVisible"
QT_MOC_LITERAL(45, 500, 16), // "showConfigDialog"
QT_MOC_LITERAL(46, 517, 19), // "showAddPluginDialog"
QT_MOC_LITERAL(47, 537, 7), // "realign"
QT_MOC_LITERAL(48, 545, 11), // "pluginMoved"
QT_MOC_LITERAL(49, 557, 7), // "Plugin*"
QT_MOC_LITERAL(50, 565, 4), // "plug"
QT_MOC_LITERAL(51, 570, 22) // "userRequestForDeletion"

    },
    "LXQtPanel\0realigned\0\0deletedByUser\0"
    "LXQtPanel*\0self\0pluginAdded\0pluginRemoved\0"
    "show\0showPanel\0animate\0hidePanel\0"
    "hidePanelWork\0setPanelSize\0value\0save\0"
    "setIconSize\0setLineCount\0setLength\0"
    "length\0inPercents\0setPosition\0screen\0"
    "ILXQtPanel::Position\0position\0"
    "setAlignment\0LXQtPanel::Alignment\0"
    "setFontColor\0color\0setBackgroundColor\0"
    "setBackgroundImage\0path\0setOpacity\0"
    "opacity\0setReserveSpace\0reserveSpace\0"
    "setHidable\0hidable\0setAnimationTime\0"
    "animationTime\0setShowDelay\0showDelay\0"
    "saveSettings\0later\0ensureVisible\0"
    "showConfigDialog\0showAddPluginDialog\0"
    "realign\0pluginMoved\0Plugin*\0plug\0"
    "userRequestForDeletion"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_LXQtPanel[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      30,   14, // methods
       1,  262, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  164,    2, 0x06 /* Public */,
       3,    1,  165,    2, 0x06 /* Public */,
       6,    0,  168,    2, 0x06 /* Public */,
       7,    0,  169,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    0,  170,    2, 0x0a /* Public */,
       9,    1,  171,    2, 0x0a /* Public */,
      11,    0,  174,    2, 0x0a /* Public */,
      12,    0,  175,    2, 0x0a /* Public */,
      13,    2,  176,    2, 0x0a /* Public */,
      16,    2,  181,    2, 0x0a /* Public */,
      17,    2,  186,    2, 0x0a /* Public */,
      18,    3,  191,    2, 0x0a /* Public */,
      21,    3,  198,    2, 0x0a /* Public */,
      25,    2,  205,    2, 0x0a /* Public */,
      27,    2,  210,    2, 0x0a /* Public */,
      29,    2,  215,    2, 0x0a /* Public */,
      30,    2,  220,    2, 0x0a /* Public */,
      32,    2,  225,    2, 0x0a /* Public */,
      34,    2,  230,    2, 0x0a /* Public */,
      36,    2,  235,    2, 0x0a /* Public */,
      38,    2,  240,    2, 0x0a /* Public */,
      40,    2,  245,    2, 0x0a /* Public */,
      42,    1,  250,    2, 0x0a /* Public */,
      42,    0,  253,    2, 0x2a /* Public | MethodCloned */,
      44,    0,  254,    2, 0x0a /* Public */,
      45,    0,  255,    2, 0x0a /* Public */,
      46,    0,  256,    2, 0x08 /* Private */,
      47,    0,  257,    2, 0x08 /* Private */,
      48,    1,  258,    2, 0x08 /* Private */,
      51,    0,  261,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   10,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Bool,   14,   15,
    QMetaType::Void, QMetaType::Int, QMetaType::Bool,   14,   15,
    QMetaType::Void, QMetaType::Int, QMetaType::Bool,   14,   15,
    QMetaType::Void, QMetaType::Int, QMetaType::Bool, QMetaType::Bool,   19,   20,   15,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 23, QMetaType::Bool,   22,   24,   15,
    QMetaType::Void, 0x80000000 | 26, QMetaType::Bool,   14,   15,
    QMetaType::Void, QMetaType::QColor, QMetaType::Bool,   28,   15,
    QMetaType::Void, QMetaType::QColor, QMetaType::Bool,   28,   15,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool,   31,   15,
    QMetaType::Void, QMetaType::Int, QMetaType::Bool,   33,   15,
    QMetaType::Void, QMetaType::Bool, QMetaType::Bool,   35,   15,
    QMetaType::Void, QMetaType::Bool, QMetaType::Bool,   37,   15,
    QMetaType::Void, QMetaType::Int, QMetaType::Bool,   39,   15,
    QMetaType::Void, QMetaType::Int, QMetaType::Bool,   41,   15,
    QMetaType::Void, QMetaType::Bool,   43,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 49,   50,
    QMetaType::Void,

 // properties: name, type, flags
      24, QMetaType::QString, 0x00095001,

       0        // eod
};

void LXQtPanel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        LXQtPanel *_t = static_cast<LXQtPanel *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->realigned(); break;
        case 1: _t->deletedByUser((*reinterpret_cast< LXQtPanel*(*)>(_a[1]))); break;
        case 2: _t->pluginAdded(); break;
        case 3: _t->pluginRemoved(); break;
        case 4: _t->show(); break;
        case 5: _t->showPanel((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->hidePanel(); break;
        case 7: _t->hidePanelWork(); break;
        case 8: _t->setPanelSize((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 9: _t->setIconSize((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 10: _t->setLineCount((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 11: _t->setLength((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 12: _t->setPosition((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< ILXQtPanel::Position(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 13: _t->setAlignment((*reinterpret_cast< LXQtPanel::Alignment(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 14: _t->setFontColor((*reinterpret_cast< QColor(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 15: _t->setBackgroundColor((*reinterpret_cast< QColor(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 16: _t->setBackgroundImage((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 17: _t->setOpacity((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 18: _t->setReserveSpace((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 19: _t->setHidable((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 20: _t->setAnimationTime((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 21: _t->setShowDelay((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 22: _t->saveSettings((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 23: _t->saveSettings(); break;
        case 24: _t->ensureVisible(); break;
        case 25: _t->showConfigDialog(); break;
        case 26: _t->showAddPluginDialog(); break;
        case 27: _t->realign(); break;
        case 28: _t->pluginMoved((*reinterpret_cast< Plugin*(*)>(_a[1]))); break;
        case 29: _t->userRequestForDeletion(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< LXQtPanel* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (LXQtPanel::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&LXQtPanel::realigned)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (LXQtPanel::*_t)(LXQtPanel * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&LXQtPanel::deletedByUser)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (LXQtPanel::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&LXQtPanel::pluginAdded)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (LXQtPanel::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&LXQtPanel::pluginRemoved)) {
                *result = 3;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        LXQtPanel *_t = static_cast<LXQtPanel *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->qssPosition(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject LXQtPanel::staticMetaObject = {
    { &QFrame::staticMetaObject, qt_meta_stringdata_LXQtPanel.data,
      qt_meta_data_LXQtPanel,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *LXQtPanel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LXQtPanel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_LXQtPanel.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "ILXQtPanel"))
        return static_cast< ILXQtPanel*>(this);
    return QFrame::qt_metacast(_clname);
}

int LXQtPanel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void LXQtPanel::realigned()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void LXQtPanel::deletedByUser(LXQtPanel * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void LXQtPanel::pluginAdded()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void LXQtPanel::pluginRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
