/****************************************************************************
** Meta object code from reading C++ file 'lxqtquicklaunch.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/lxqt-panel-0.12.0/plugin-quicklaunch/lxqtquicklaunch.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'lxqtquicklaunch.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_LXQtQuickLaunch_t {
    QByteArrayData data[12];
    char stringdata0[147];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_LXQtQuickLaunch_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_LXQtQuickLaunch_t qt_meta_stringdata_LXQtQuickLaunch = {
    {
QT_MOC_LITERAL(0, 0, 15), // "LXQtQuickLaunch"
QT_MOC_LITERAL(1, 16, 9), // "addButton"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 18), // "QuickLaunchAction*"
QT_MOC_LITERAL(4, 46, 6), // "action"
QT_MOC_LITERAL(5, 53, 13), // "switchButtons"
QT_MOC_LITERAL(6, 67, 18), // "QuickLaunchButton*"
QT_MOC_LITERAL(7, 86, 7), // "button1"
QT_MOC_LITERAL(8, 94, 7), // "button2"
QT_MOC_LITERAL(9, 102, 13), // "buttonDeleted"
QT_MOC_LITERAL(10, 116, 14), // "buttonMoveLeft"
QT_MOC_LITERAL(11, 131, 15) // "buttonMoveRight"

    },
    "LXQtQuickLaunch\0addButton\0\0"
    "QuickLaunchAction*\0action\0switchButtons\0"
    "QuickLaunchButton*\0button1\0button2\0"
    "buttonDeleted\0buttonMoveLeft\0"
    "buttonMoveRight"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_LXQtQuickLaunch[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   39,    2, 0x08 /* Private */,
       5,    2,   42,    2, 0x08 /* Private */,
       9,    0,   47,    2, 0x08 /* Private */,
      10,    0,   48,    2, 0x08 /* Private */,
      11,    0,   49,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 6, 0x80000000 | 6,    7,    8,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void LXQtQuickLaunch::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        LXQtQuickLaunch *_t = static_cast<LXQtQuickLaunch *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->addButton((*reinterpret_cast< QuickLaunchAction*(*)>(_a[1]))); break;
        case 1: _t->switchButtons((*reinterpret_cast< QuickLaunchButton*(*)>(_a[1])),(*reinterpret_cast< QuickLaunchButton*(*)>(_a[2]))); break;
        case 2: _t->buttonDeleted(); break;
        case 3: _t->buttonMoveLeft(); break;
        case 4: _t->buttonMoveRight(); break;
        default: ;
        }
    }
}

const QMetaObject LXQtQuickLaunch::staticMetaObject = {
    { &QFrame::staticMetaObject, qt_meta_stringdata_LXQtQuickLaunch.data,
      qt_meta_data_LXQtQuickLaunch,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *LXQtQuickLaunch::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LXQtQuickLaunch::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_LXQtQuickLaunch.stringdata0))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int LXQtQuickLaunch::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
