/********************************************************************************
** Form generated from reading UI file 'lxqtworldclockconfiguration.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LXQTWORLDCLOCKCONFIGURATION_H
#define UI_LXQTWORLDCLOCKCONFIGURATION_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_LXQtWorldClockConfiguration
{
public:
    QVBoxLayout *_6;
    QTabWidget *tabWidget;
    QWidget *displayFormatT;
    QVBoxLayout *_8;
    QGroupBox *timeGB;
    QFormLayout *formLayout;
    QLabel *timeFormatL;
    QComboBox *timeFormatCB;
    QWidget *timeCustomLabelW;
    QWidget *timeCustomW;
    QVBoxLayout *verticalLayout_5;
    QCheckBox *timeShowSecondsCB;
    QCheckBox *timePadHourCB;
    QCheckBox *timeAMPMCB;
    QGroupBox *timezoneGB;
    QFormLayout *formLayout_3;
    QLabel *timezonePositionL;
    QLabel *timezoneFormatL;
    QComboBox *timezonePositionCB;
    QComboBox *timezoneFormatCB;
    QGroupBox *dateGB;
    QFormLayout *formLayout_2;
    QLabel *datePositionL;
    QComboBox *datePositionCB;
    QLabel *dateFormatL;
    QComboBox *dateFormatCB;
    QWidget *dateCustomLabelW;
    QWidget *dateCustomW;
    QVBoxLayout *verticalLayout_3;
    QCheckBox *dateShowYearCB;
    QCheckBox *dateShowDoWCB;
    QCheckBox *datePadDayCB;
    QCheckBox *dateLongNamesCB;
    QGroupBox *advancedManualGB;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *_3;
    QPushButton *customisePB;
    QSpacerItem *_1;
    QWidget *timeZonesT;
    QHBoxLayout *_7;
    QTableWidget *timeZonesTW;
    QVBoxLayout *_2;
    QPushButton *addPB;
    QPushButton *removePB;
    QPushButton *setAsDefaultPB;
    QPushButton *editCustomNamePB;
    QPushButton *moveUpPB;
    QPushButton *moveDownPB;
    QSpacerItem *spacer;
    QWidget *generalT;
    QVBoxLayout *verticalLayout;
    QCheckBox *autorotateCB;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttons;

    void setupUi(QDialog *LXQtWorldClockConfiguration)
    {
        if (LXQtWorldClockConfiguration->objectName().isEmpty())
            LXQtWorldClockConfiguration->setObjectName(QStringLiteral("LXQtWorldClockConfiguration"));
        LXQtWorldClockConfiguration->resize(600, 686);
        _6 = new QVBoxLayout(LXQtWorldClockConfiguration);
        _6->setObjectName(QStringLiteral("_6"));
        tabWidget = new QTabWidget(LXQtWorldClockConfiguration);
        tabWidget->setObjectName(QStringLiteral("tabWidget"));
        displayFormatT = new QWidget();
        displayFormatT->setObjectName(QStringLiteral("displayFormatT"));
        _8 = new QVBoxLayout(displayFormatT);
        _8->setObjectName(QStringLiteral("_8"));
        timeGB = new QGroupBox(displayFormatT);
        timeGB->setObjectName(QStringLiteral("timeGB"));
        formLayout = new QFormLayout(timeGB);
        formLayout->setObjectName(QStringLiteral("formLayout"));
        formLayout->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        timeFormatL = new QLabel(timeGB);
        timeFormatL->setObjectName(QStringLiteral("timeFormatL"));

        formLayout->setWidget(0, QFormLayout::LabelRole, timeFormatL);

        timeFormatCB = new QComboBox(timeGB);
        timeFormatCB->setObjectName(QStringLiteral("timeFormatCB"));

        formLayout->setWidget(0, QFormLayout::FieldRole, timeFormatCB);

        timeCustomLabelW = new QWidget(timeGB);
        timeCustomLabelW->setObjectName(QStringLiteral("timeCustomLabelW"));

        formLayout->setWidget(1, QFormLayout::LabelRole, timeCustomLabelW);

        timeCustomW = new QWidget(timeGB);
        timeCustomW->setObjectName(QStringLiteral("timeCustomW"));
        timeCustomW->setEnabled(false);
        verticalLayout_5 = new QVBoxLayout(timeCustomW);
        verticalLayout_5->setObjectName(QStringLiteral("verticalLayout_5"));
        verticalLayout_5->setContentsMargins(0, 0, 0, 0);
        timeShowSecondsCB = new QCheckBox(timeCustomW);
        timeShowSecondsCB->setObjectName(QStringLiteral("timeShowSecondsCB"));

        verticalLayout_5->addWidget(timeShowSecondsCB);

        timePadHourCB = new QCheckBox(timeCustomW);
        timePadHourCB->setObjectName(QStringLiteral("timePadHourCB"));

        verticalLayout_5->addWidget(timePadHourCB);

        timeAMPMCB = new QCheckBox(timeCustomW);
        timeAMPMCB->setObjectName(QStringLiteral("timeAMPMCB"));

        verticalLayout_5->addWidget(timeAMPMCB);


        formLayout->setWidget(1, QFormLayout::FieldRole, timeCustomW);


        _8->addWidget(timeGB);

        timezoneGB = new QGroupBox(displayFormatT);
        timezoneGB->setObjectName(QStringLiteral("timezoneGB"));
        timezoneGB->setCheckable(true);
        timezoneGB->setChecked(false);
        formLayout_3 = new QFormLayout(timezoneGB);
        formLayout_3->setObjectName(QStringLiteral("formLayout_3"));
        timezonePositionL = new QLabel(timezoneGB);
        timezonePositionL->setObjectName(QStringLiteral("timezonePositionL"));

        formLayout_3->setWidget(0, QFormLayout::LabelRole, timezonePositionL);

        timezoneFormatL = new QLabel(timezoneGB);
        timezoneFormatL->setObjectName(QStringLiteral("timezoneFormatL"));

        formLayout_3->setWidget(1, QFormLayout::LabelRole, timezoneFormatL);

        timezonePositionCB = new QComboBox(timezoneGB);
        timezonePositionCB->setObjectName(QStringLiteral("timezonePositionCB"));

        formLayout_3->setWidget(0, QFormLayout::FieldRole, timezonePositionCB);

        timezoneFormatCB = new QComboBox(timezoneGB);
        timezoneFormatCB->setObjectName(QStringLiteral("timezoneFormatCB"));

        formLayout_3->setWidget(1, QFormLayout::FieldRole, timezoneFormatCB);


        _8->addWidget(timezoneGB);

        dateGB = new QGroupBox(displayFormatT);
        dateGB->setObjectName(QStringLiteral("dateGB"));
        dateGB->setCheckable(true);
        dateGB->setChecked(false);
        formLayout_2 = new QFormLayout(dateGB);
        formLayout_2->setObjectName(QStringLiteral("formLayout_2"));
        formLayout_2->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        datePositionL = new QLabel(dateGB);
        datePositionL->setObjectName(QStringLiteral("datePositionL"));

        formLayout_2->setWidget(0, QFormLayout::LabelRole, datePositionL);

        datePositionCB = new QComboBox(dateGB);
        datePositionCB->setObjectName(QStringLiteral("datePositionCB"));

        formLayout_2->setWidget(0, QFormLayout::FieldRole, datePositionCB);

        dateFormatL = new QLabel(dateGB);
        dateFormatL->setObjectName(QStringLiteral("dateFormatL"));

        formLayout_2->setWidget(1, QFormLayout::LabelRole, dateFormatL);

        dateFormatCB = new QComboBox(dateGB);
        dateFormatCB->setObjectName(QStringLiteral("dateFormatCB"));

        formLayout_2->setWidget(1, QFormLayout::FieldRole, dateFormatCB);

        dateCustomLabelW = new QWidget(dateGB);
        dateCustomLabelW->setObjectName(QStringLiteral("dateCustomLabelW"));

        formLayout_2->setWidget(2, QFormLayout::LabelRole, dateCustomLabelW);

        dateCustomW = new QWidget(dateGB);
        dateCustomW->setObjectName(QStringLiteral("dateCustomW"));
        dateCustomW->setEnabled(false);
        verticalLayout_3 = new QVBoxLayout(dateCustomW);
        verticalLayout_3->setObjectName(QStringLiteral("verticalLayout_3"));
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        dateShowYearCB = new QCheckBox(dateCustomW);
        dateShowYearCB->setObjectName(QStringLiteral("dateShowYearCB"));

        verticalLayout_3->addWidget(dateShowYearCB);

        dateShowDoWCB = new QCheckBox(dateCustomW);
        dateShowDoWCB->setObjectName(QStringLiteral("dateShowDoWCB"));

        verticalLayout_3->addWidget(dateShowDoWCB);

        datePadDayCB = new QCheckBox(dateCustomW);
        datePadDayCB->setObjectName(QStringLiteral("datePadDayCB"));

        verticalLayout_3->addWidget(datePadDayCB);

        dateLongNamesCB = new QCheckBox(dateCustomW);
        dateLongNamesCB->setObjectName(QStringLiteral("dateLongNamesCB"));

        verticalLayout_3->addWidget(dateLongNamesCB);


        formLayout_2->setWidget(2, QFormLayout::FieldRole, dateCustomW);


        _8->addWidget(dateGB);

        advancedManualGB = new QGroupBox(displayFormatT);
        advancedManualGB->setObjectName(QStringLiteral("advancedManualGB"));
        advancedManualGB->setCheckable(true);
        advancedManualGB->setChecked(false);
        verticalLayout_2 = new QVBoxLayout(advancedManualGB);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        _3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(_3);

        customisePB = new QPushButton(advancedManualGB);
        customisePB->setObjectName(QStringLiteral("customisePB"));

        horizontalLayout->addWidget(customisePB);


        verticalLayout_2->addLayout(horizontalLayout);


        _8->addWidget(advancedManualGB);

        _1 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        _8->addItem(_1);

        tabWidget->addTab(displayFormatT, QString());
        timeZonesT = new QWidget();
        timeZonesT->setObjectName(QStringLiteral("timeZonesT"));
        _7 = new QHBoxLayout(timeZonesT);
        _7->setObjectName(QStringLiteral("_7"));
        timeZonesTW = new QTableWidget(timeZonesT);
        if (timeZonesTW->columnCount() < 2)
            timeZonesTW->setColumnCount(2);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        timeZonesTW->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        timeZonesTW->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        timeZonesTW->setObjectName(QStringLiteral("timeZonesTW"));
        timeZonesTW->setEditTriggers(QAbstractItemView::NoEditTriggers);
        timeZonesTW->setAlternatingRowColors(true);
        timeZonesTW->setSelectionMode(QAbstractItemView::ExtendedSelection);
        timeZonesTW->setSelectionBehavior(QAbstractItemView::SelectRows);
        timeZonesTW->setColumnCount(2);
        timeZonesTW->horizontalHeader()->setStretchLastSection(true);
        timeZonesTW->verticalHeader()->setVisible(false);

        _7->addWidget(timeZonesTW);

        _2 = new QVBoxLayout();
        _2->setObjectName(QStringLiteral("_2"));
        addPB = new QPushButton(timeZonesT);
        addPB->setObjectName(QStringLiteral("addPB"));

        _2->addWidget(addPB);

        removePB = new QPushButton(timeZonesT);
        removePB->setObjectName(QStringLiteral("removePB"));
        removePB->setEnabled(false);

        _2->addWidget(removePB);

        setAsDefaultPB = new QPushButton(timeZonesT);
        setAsDefaultPB->setObjectName(QStringLiteral("setAsDefaultPB"));
        setAsDefaultPB->setEnabled(false);

        _2->addWidget(setAsDefaultPB);

        editCustomNamePB = new QPushButton(timeZonesT);
        editCustomNamePB->setObjectName(QStringLiteral("editCustomNamePB"));
        editCustomNamePB->setEnabled(false);

        _2->addWidget(editCustomNamePB);

        moveUpPB = new QPushButton(timeZonesT);
        moveUpPB->setObjectName(QStringLiteral("moveUpPB"));
        moveUpPB->setEnabled(false);

        _2->addWidget(moveUpPB);

        moveDownPB = new QPushButton(timeZonesT);
        moveDownPB->setObjectName(QStringLiteral("moveDownPB"));
        moveDownPB->setEnabled(false);

        _2->addWidget(moveDownPB);

        spacer = new QSpacerItem(1, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        _2->addItem(spacer);


        _7->addLayout(_2);

        tabWidget->addTab(timeZonesT, QString());
        generalT = new QWidget();
        generalT->setObjectName(QStringLiteral("generalT"));
        verticalLayout = new QVBoxLayout(generalT);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        autorotateCB = new QCheckBox(generalT);
        autorotateCB->setObjectName(QStringLiteral("autorotateCB"));
        autorotateCB->setChecked(true);

        verticalLayout->addWidget(autorotateCB);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        tabWidget->addTab(generalT, QString());

        _6->addWidget(tabWidget);

        buttons = new QDialogButtonBox(LXQtWorldClockConfiguration);
        buttons->setObjectName(QStringLiteral("buttons"));
        buttons->setOrientation(Qt::Horizontal);
        buttons->setStandardButtons(QDialogButtonBox::Close|QDialogButtonBox::Reset);

        _6->addWidget(buttons);

#ifndef QT_NO_SHORTCUT
        timeFormatL->setBuddy(timeFormatCB);
        timezonePositionL->setBuddy(timezonePositionCB);
        timezoneFormatL->setBuddy(timezoneFormatCB);
        datePositionL->setBuddy(datePositionCB);
        dateFormatL->setBuddy(dateFormatCB);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(tabWidget, timeFormatCB);
        QWidget::setTabOrder(timeFormatCB, timeShowSecondsCB);
        QWidget::setTabOrder(timeShowSecondsCB, timePadHourCB);
        QWidget::setTabOrder(timePadHourCB, timeAMPMCB);
        QWidget::setTabOrder(timeAMPMCB, timezoneGB);
        QWidget::setTabOrder(timezoneGB, timezonePositionCB);
        QWidget::setTabOrder(timezonePositionCB, timezoneFormatCB);
        QWidget::setTabOrder(timezoneFormatCB, dateGB);
        QWidget::setTabOrder(dateGB, datePositionCB);
        QWidget::setTabOrder(datePositionCB, dateFormatCB);
        QWidget::setTabOrder(dateFormatCB, dateShowYearCB);
        QWidget::setTabOrder(dateShowYearCB, dateShowDoWCB);
        QWidget::setTabOrder(dateShowDoWCB, datePadDayCB);
        QWidget::setTabOrder(datePadDayCB, dateLongNamesCB);
        QWidget::setTabOrder(dateLongNamesCB, advancedManualGB);
        QWidget::setTabOrder(advancedManualGB, customisePB);
        QWidget::setTabOrder(customisePB, timeZonesTW);
        QWidget::setTabOrder(timeZonesTW, addPB);
        QWidget::setTabOrder(addPB, removePB);
        QWidget::setTabOrder(removePB, setAsDefaultPB);
        QWidget::setTabOrder(setAsDefaultPB, editCustomNamePB);
        QWidget::setTabOrder(editCustomNamePB, moveUpPB);
        QWidget::setTabOrder(moveUpPB, moveDownPB);
        QWidget::setTabOrder(moveDownPB, autorotateCB);
        QWidget::setTabOrder(autorotateCB, buttons);

        retranslateUi(LXQtWorldClockConfiguration);
        QObject::connect(buttons, SIGNAL(accepted()), LXQtWorldClockConfiguration, SLOT(accept()));
        QObject::connect(buttons, SIGNAL(rejected()), LXQtWorldClockConfiguration, SLOT(reject()));

        tabWidget->setCurrentIndex(0);
        timezoneFormatCB->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(LXQtWorldClockConfiguration);
    } // setupUi

    void retranslateUi(QDialog *LXQtWorldClockConfiguration)
    {
        LXQtWorldClockConfiguration->setWindowTitle(QApplication::translate("LXQtWorldClockConfiguration", "World Clock Settings", Q_NULLPTR));
        timeGB->setTitle(QApplication::translate("LXQtWorldClockConfiguration", "&Time", Q_NULLPTR));
        timeFormatL->setText(QApplication::translate("LXQtWorldClockConfiguration", "F&ormat:", Q_NULLPTR));
        timeFormatCB->clear();
        timeFormatCB->insertItems(0, QStringList()
         << QApplication::translate("LXQtWorldClockConfiguration", "Short", Q_NULLPTR)
         << QApplication::translate("LXQtWorldClockConfiguration", "Long", Q_NULLPTR)
         << QApplication::translate("LXQtWorldClockConfiguration", "Custom", Q_NULLPTR)
        );
        timeShowSecondsCB->setText(QApplication::translate("LXQtWorldClockConfiguration", "Sho&w seconds", Q_NULLPTR));
        timePadHourCB->setText(QApplication::translate("LXQtWorldClockConfiguration", "Pad &hour with zero", Q_NULLPTR));
        timeAMPMCB->setText(QApplication::translate("LXQtWorldClockConfiguration", "&Use 12-hour format", Q_NULLPTR));
        timezoneGB->setTitle(QApplication::translate("LXQtWorldClockConfiguration", "T&ime zone", Q_NULLPTR));
        timezonePositionL->setText(QApplication::translate("LXQtWorldClockConfiguration", "&Position:", Q_NULLPTR));
        timezoneFormatL->setText(QApplication::translate("LXQtWorldClockConfiguration", "For&mat:", Q_NULLPTR));
        timezonePositionCB->clear();
        timezonePositionCB->insertItems(0, QStringList()
         << QApplication::translate("LXQtWorldClockConfiguration", "Below", Q_NULLPTR)
         << QApplication::translate("LXQtWorldClockConfiguration", "Above", Q_NULLPTR)
         << QApplication::translate("LXQtWorldClockConfiguration", "Before", Q_NULLPTR)
         << QApplication::translate("LXQtWorldClockConfiguration", "After", Q_NULLPTR)
        );
        timezoneFormatCB->clear();
        timezoneFormatCB->insertItems(0, QStringList()
         << QApplication::translate("LXQtWorldClockConfiguration", "Short", Q_NULLPTR)
         << QApplication::translate("LXQtWorldClockConfiguration", "Long", Q_NULLPTR)
         << QApplication::translate("LXQtWorldClockConfiguration", "Offset from UTC", Q_NULLPTR)
         << QApplication::translate("LXQtWorldClockConfiguration", "Abbreviation", Q_NULLPTR)
         << QApplication::translate("LXQtWorldClockConfiguration", "Location identifier", Q_NULLPTR)
         << QApplication::translate("LXQtWorldClockConfiguration", "Custom name", Q_NULLPTR)
        );
        dateGB->setTitle(QApplication::translate("LXQtWorldClockConfiguration", "&Date", Q_NULLPTR));
        datePositionL->setText(QApplication::translate("LXQtWorldClockConfiguration", "Po&sition:", Q_NULLPTR));
        datePositionCB->clear();
        datePositionCB->insertItems(0, QStringList()
         << QApplication::translate("LXQtWorldClockConfiguration", "Below", Q_NULLPTR)
         << QApplication::translate("LXQtWorldClockConfiguration", "Above", Q_NULLPTR)
         << QApplication::translate("LXQtWorldClockConfiguration", "Before", Q_NULLPTR)
         << QApplication::translate("LXQtWorldClockConfiguration", "After", Q_NULLPTR)
        );
        dateFormatL->setText(QApplication::translate("LXQtWorldClockConfiguration", "Fo&rmat:", Q_NULLPTR));
        dateFormatCB->clear();
        dateFormatCB->insertItems(0, QStringList()
         << QApplication::translate("LXQtWorldClockConfiguration", "Short", Q_NULLPTR)
         << QApplication::translate("LXQtWorldClockConfiguration", "Long", Q_NULLPTR)
         << QApplication::translate("LXQtWorldClockConfiguration", "ISO 8601", Q_NULLPTR)
         << QApplication::translate("LXQtWorldClockConfiguration", "Custom", Q_NULLPTR)
        );
        dateShowYearCB->setText(QApplication::translate("LXQtWorldClockConfiguration", "Show &year", Q_NULLPTR));
        dateShowDoWCB->setText(QApplication::translate("LXQtWorldClockConfiguration", "Show day of wee&k", Q_NULLPTR));
        datePadDayCB->setText(QApplication::translate("LXQtWorldClockConfiguration", "Pad d&ay with zero", Q_NULLPTR));
        dateLongNamesCB->setText(QApplication::translate("LXQtWorldClockConfiguration", "&Long month and day of week names", Q_NULLPTR));
        advancedManualGB->setTitle(QApplication::translate("LXQtWorldClockConfiguration", "Ad&vanced manual format", Q_NULLPTR));
        customisePB->setText(QApplication::translate("LXQtWorldClockConfiguration", "&Customise ...", Q_NULLPTR));
        tabWidget->setTabText(tabWidget->indexOf(displayFormatT), QApplication::translate("LXQtWorldClockConfiguration", "Display &format", Q_NULLPTR));
        QTableWidgetItem *___qtablewidgetitem = timeZonesTW->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(QApplication::translate("LXQtWorldClockConfiguration", "IANA id", Q_NULLPTR));
        QTableWidgetItem *___qtablewidgetitem1 = timeZonesTW->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(QApplication::translate("LXQtWorldClockConfiguration", "Custom name", Q_NULLPTR));
        addPB->setText(QApplication::translate("LXQtWorldClockConfiguration", "&Add ...", Q_NULLPTR));
        removePB->setText(QApplication::translate("LXQtWorldClockConfiguration", "&Remove", Q_NULLPTR));
        setAsDefaultPB->setText(QApplication::translate("LXQtWorldClockConfiguration", "Set as &default", Q_NULLPTR));
        editCustomNamePB->setText(QApplication::translate("LXQtWorldClockConfiguration", "&Edit custom name ...", Q_NULLPTR));
        moveUpPB->setText(QApplication::translate("LXQtWorldClockConfiguration", "Move &up", Q_NULLPTR));
        moveDownPB->setText(QApplication::translate("LXQtWorldClockConfiguration", "Move do&wn", Q_NULLPTR));
        tabWidget->setTabText(tabWidget->indexOf(timeZonesT), QApplication::translate("LXQtWorldClockConfiguration", "Time &zones", Q_NULLPTR));
        autorotateCB->setText(QApplication::translate("LXQtWorldClockConfiguration", "Auto&rotate when the panel is vertical", Q_NULLPTR));
        tabWidget->setTabText(tabWidget->indexOf(generalT), QApplication::translate("LXQtWorldClockConfiguration", "&General", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class LXQtWorldClockConfiguration: public Ui_LXQtWorldClockConfiguration {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LXQTWORLDCLOCKCONFIGURATION_H
