/********************************************************************************
** Form generated from reading UI file 'lxqtclockconfiguration.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LXQTCLOCKCONFIGURATION_H
#define UI_LXQTCLOCKCONFIGURATION_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_LXQtClockConfiguration
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *timeGB;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *showSecondsCB;
    QCheckBox *ampmClockCB;
    QCheckBox *useUtcCB;
    QGroupBox *dateGB;
    QGridLayout *gridLayout_2;
    QLabel *dateFormatL;
    QComboBox *dateFormatCOB;
    QRadioButton *dontShowDateRB;
    QRadioButton *showDateBeforeTimeRB;
    QRadioButton *showDateAfterTimeRB;
    QRadioButton *showDateBelowTimeRB;
    QLabel *firstDayOfWeekL;
    QComboBox *firstDayOfWeekCB;
    QGroupBox *orientationGB;
    QVBoxLayout *verticalLayout_3;
    QCheckBox *autorotateCB;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttons;

    void setupUi(QDialog *LXQtClockConfiguration)
    {
        if (LXQtClockConfiguration->objectName().isEmpty())
            LXQtClockConfiguration->setObjectName(QStringLiteral("LXQtClockConfiguration"));
        LXQtClockConfiguration->resize(330, 447);
        verticalLayout = new QVBoxLayout(LXQtClockConfiguration);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        timeGB = new QGroupBox(LXQtClockConfiguration);
        timeGB->setObjectName(QStringLiteral("timeGB"));
        verticalLayout_2 = new QVBoxLayout(timeGB);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        showSecondsCB = new QCheckBox(timeGB);
        showSecondsCB->setObjectName(QStringLiteral("showSecondsCB"));

        verticalLayout_2->addWidget(showSecondsCB);

        ampmClockCB = new QCheckBox(timeGB);
        ampmClockCB->setObjectName(QStringLiteral("ampmClockCB"));

        verticalLayout_2->addWidget(ampmClockCB);

        useUtcCB = new QCheckBox(timeGB);
        useUtcCB->setObjectName(QStringLiteral("useUtcCB"));

        verticalLayout_2->addWidget(useUtcCB);


        verticalLayout->addWidget(timeGB);

        dateGB = new QGroupBox(LXQtClockConfiguration);
        dateGB->setObjectName(QStringLiteral("dateGB"));
        gridLayout_2 = new QGridLayout(dateGB);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        dateFormatL = new QLabel(dateGB);
        dateFormatL->setObjectName(QStringLiteral("dateFormatL"));
        dateFormatL->setEnabled(false);

        gridLayout_2->addWidget(dateFormatL, 4, 0, 1, 1);

        dateFormatCOB = new QComboBox(dateGB);
        dateFormatCOB->setObjectName(QStringLiteral("dateFormatCOB"));
        dateFormatCOB->setEnabled(false);

        gridLayout_2->addWidget(dateFormatCOB, 4, 1, 1, 1);

        dontShowDateRB = new QRadioButton(dateGB);
        dontShowDateRB->setObjectName(QStringLiteral("dontShowDateRB"));
        dontShowDateRB->setChecked(true);

        gridLayout_2->addWidget(dontShowDateRB, 0, 0, 1, 2);

        showDateBeforeTimeRB = new QRadioButton(dateGB);
        showDateBeforeTimeRB->setObjectName(QStringLiteral("showDateBeforeTimeRB"));

        gridLayout_2->addWidget(showDateBeforeTimeRB, 1, 0, 1, 2);

        showDateAfterTimeRB = new QRadioButton(dateGB);
        showDateAfterTimeRB->setObjectName(QStringLiteral("showDateAfterTimeRB"));

        gridLayout_2->addWidget(showDateAfterTimeRB, 2, 0, 1, 2);

        showDateBelowTimeRB = new QRadioButton(dateGB);
        showDateBelowTimeRB->setObjectName(QStringLiteral("showDateBelowTimeRB"));

        gridLayout_2->addWidget(showDateBelowTimeRB, 3, 0, 1, 2);

        firstDayOfWeekL = new QLabel(dateGB);
        firstDayOfWeekL->setObjectName(QStringLiteral("firstDayOfWeekL"));

        gridLayout_2->addWidget(firstDayOfWeekL, 5, 0, 1, 1);

        firstDayOfWeekCB = new QComboBox(dateGB);
        firstDayOfWeekCB->setObjectName(QStringLiteral("firstDayOfWeekCB"));

        gridLayout_2->addWidget(firstDayOfWeekCB, 5, 1, 1, 1);

        gridLayout_2->setColumnStretch(1, 1);

        verticalLayout->addWidget(dateGB);

        orientationGB = new QGroupBox(LXQtClockConfiguration);
        orientationGB->setObjectName(QStringLiteral("orientationGB"));
        verticalLayout_3 = new QVBoxLayout(orientationGB);
        verticalLayout_3->setObjectName(QStringLiteral("verticalLayout_3"));
        autorotateCB = new QCheckBox(orientationGB);
        autorotateCB->setObjectName(QStringLiteral("autorotateCB"));
        autorotateCB->setChecked(true);

        verticalLayout_3->addWidget(autorotateCB);


        verticalLayout->addWidget(orientationGB);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttons = new QDialogButtonBox(LXQtClockConfiguration);
        buttons->setObjectName(QStringLiteral("buttons"));
        buttons->setOrientation(Qt::Horizontal);
        buttons->setStandardButtons(QDialogButtonBox::Close|QDialogButtonBox::Reset);

        verticalLayout->addWidget(buttons);

#ifndef QT_NO_SHORTCUT
        dateFormatL->setBuddy(dateFormatCOB);
        firstDayOfWeekL->setBuddy(firstDayOfWeekCB);
#endif // QT_NO_SHORTCUT

        retranslateUi(LXQtClockConfiguration);
        QObject::connect(buttons, SIGNAL(accepted()), LXQtClockConfiguration, SLOT(accept()));
        QObject::connect(buttons, SIGNAL(rejected()), LXQtClockConfiguration, SLOT(reject()));
        QObject::connect(dontShowDateRB, SIGNAL(toggled(bool)), dateFormatL, SLOT(setDisabled(bool)));
        QObject::connect(dontShowDateRB, SIGNAL(toggled(bool)), dateFormatCOB, SLOT(setDisabled(bool)));

        QMetaObject::connectSlotsByName(LXQtClockConfiguration);
    } // setupUi

    void retranslateUi(QDialog *LXQtClockConfiguration)
    {
        LXQtClockConfiguration->setWindowTitle(QApplication::translate("LXQtClockConfiguration", "Clock Settings", Q_NULLPTR));
        timeGB->setTitle(QApplication::translate("LXQtClockConfiguration", "Time", Q_NULLPTR));
        showSecondsCB->setText(QApplication::translate("LXQtClockConfiguration", "&Show seconds", Q_NULLPTR));
        ampmClockCB->setText(QApplication::translate("LXQtClockConfiguration", "12 &hour style", Q_NULLPTR));
        useUtcCB->setText(QApplication::translate("LXQtClockConfiguration", "&Use UTC", Q_NULLPTR));
        dateGB->setTitle(QApplication::translate("LXQtClockConfiguration", "Date", Q_NULLPTR));
        dateFormatL->setText(QApplication::translate("LXQtClockConfiguration", "Date &format", Q_NULLPTR));
        dontShowDateRB->setText(QApplication::translate("LXQtClockConfiguration", "&Do not show date", Q_NULLPTR));
        showDateBeforeTimeRB->setText(QApplication::translate("LXQtClockConfiguration", "Show date &before time", Q_NULLPTR));
        showDateAfterTimeRB->setText(QApplication::translate("LXQtClockConfiguration", "Show date &after time", Q_NULLPTR));
        showDateBelowTimeRB->setText(QApplication::translate("LXQtClockConfiguration", "Show date below time on new &line", Q_NULLPTR));
        firstDayOfWeekL->setText(QApplication::translate("LXQtClockConfiguration", "First day of week in calendar", Q_NULLPTR));
        orientationGB->setTitle(QApplication::translate("LXQtClockConfiguration", "Orientation", Q_NULLPTR));
        autorotateCB->setText(QApplication::translate("LXQtClockConfiguration", "Auto&rotate when the panel is vertical", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class LXQtClockConfiguration: public Ui_LXQtClockConfiguration {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LXQTCLOCKCONFIGURATION_H
