/********************************************************************************
** Form generated from reading UI file 'lxqtnetworkmonitorconfiguration.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LXQTNETWORKMONITORCONFIGURATION_H
#define UI_LXQTNETWORKMONITORCONFIGURATION_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_LXQtNetworkMonitorConfiguration
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *generalGB;
    QGridLayout *gridLayout;
    QLabel *interfaceLabel;
    QComboBox *interfaceCB;
    QComboBox *iconCB;
    QLabel *iconLabel;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttons;

    void setupUi(QDialog *LXQtNetworkMonitorConfiguration)
    {
        if (LXQtNetworkMonitorConfiguration->objectName().isEmpty())
            LXQtNetworkMonitorConfiguration->setObjectName(QStringLiteral("LXQtNetworkMonitorConfiguration"));
        LXQtNetworkMonitorConfiguration->resize(285, 191);
        verticalLayout = new QVBoxLayout(LXQtNetworkMonitorConfiguration);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        generalGB = new QGroupBox(LXQtNetworkMonitorConfiguration);
        generalGB->setObjectName(QStringLiteral("generalGB"));
        generalGB->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        generalGB->setFlat(false);
        generalGB->setCheckable(false);
        gridLayout = new QGridLayout(generalGB);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        interfaceLabel = new QLabel(generalGB);
        interfaceLabel->setObjectName(QStringLiteral("interfaceLabel"));

        gridLayout->addWidget(interfaceLabel, 1, 0, 1, 1);

        interfaceCB = new QComboBox(generalGB);
        interfaceCB->setObjectName(QStringLiteral("interfaceCB"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(interfaceCB->sizePolicy().hasHeightForWidth());
        interfaceCB->setSizePolicy(sizePolicy);
        interfaceCB->setEditable(true);

        gridLayout->addWidget(interfaceCB, 1, 1, 1, 1);

        iconCB = new QComboBox(generalGB);
        QIcon icon;
        icon.addFile(QStringLiteral(":/images/knemo-modem-idle.png"), QSize(), QIcon::Normal, QIcon::Off);
        iconCB->addItem(icon, QString());
        QIcon icon1;
        icon1.addFile(QStringLiteral(":/images/knemo-monitor-idle.png"), QSize(), QIcon::Normal, QIcon::Off);
        iconCB->addItem(icon1, QString());
        QIcon icon2;
        icon2.addFile(QStringLiteral(":/images/knemo-network-idle.png"), QSize(), QIcon::Normal, QIcon::Off);
        iconCB->addItem(icon2, QString());
        QIcon icon3;
        icon3.addFile(QStringLiteral(":/images/knemo-wireless-idle.png"), QSize(), QIcon::Normal, QIcon::Off);
        iconCB->addItem(icon3, QString());
        iconCB->setObjectName(QStringLiteral("iconCB"));

        gridLayout->addWidget(iconCB, 0, 1, 1, 1);

        iconLabel = new QLabel(generalGB);
        iconLabel->setObjectName(QStringLiteral("iconLabel"));

        gridLayout->addWidget(iconLabel, 0, 0, 1, 1);


        verticalLayout->addWidget(generalGB);

        verticalSpacer = new QSpacerItem(20, 41, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttons = new QDialogButtonBox(LXQtNetworkMonitorConfiguration);
        buttons->setObjectName(QStringLiteral("buttons"));
        buttons->setOrientation(Qt::Horizontal);
        buttons->setStandardButtons(QDialogButtonBox::Close|QDialogButtonBox::Reset);

        verticalLayout->addWidget(buttons);


        retranslateUi(LXQtNetworkMonitorConfiguration);

        QMetaObject::connectSlotsByName(LXQtNetworkMonitorConfiguration);
    } // setupUi

    void retranslateUi(QDialog *LXQtNetworkMonitorConfiguration)
    {
        LXQtNetworkMonitorConfiguration->setWindowTitle(QApplication::translate("LXQtNetworkMonitorConfiguration", "Network Monitor settings", Q_NULLPTR));
        generalGB->setTitle(QApplication::translate("LXQtNetworkMonitorConfiguration", "General", Q_NULLPTR));
        interfaceLabel->setText(QApplication::translate("LXQtNetworkMonitorConfiguration", "Interface", Q_NULLPTR));
        iconCB->setItemText(0, QApplication::translate("LXQtNetworkMonitorConfiguration", "Modem", Q_NULLPTR));
        iconCB->setItemText(1, QApplication::translate("LXQtNetworkMonitorConfiguration", "Monitor", Q_NULLPTR));
        iconCB->setItemText(2, QApplication::translate("LXQtNetworkMonitorConfiguration", "Network", Q_NULLPTR));
        iconCB->setItemText(3, QApplication::translate("LXQtNetworkMonitorConfiguration", "Wireless", Q_NULLPTR));

        iconLabel->setText(QApplication::translate("LXQtNetworkMonitorConfiguration", "Icon", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class LXQtNetworkMonitorConfiguration: public Ui_LXQtNetworkMonitorConfiguration {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LXQTNETWORKMONITORCONFIGURATION_H
