/****************************************************************************
** Meta object code from reading C++ file 'lxqttaskbar.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/lxqt-panel-0.12.0/plugin-taskbar/lxqttaskbar.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'lxqttaskbar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_LXQtTaskBar_t {
    QByteArrayData data[33];
    char stringdata0[485];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_LXQtTaskBar_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_LXQtTaskBar_t qt_meta_stringdata_LXQtTaskBar = {
    {
QT_MOC_LITERAL(0, 0, 11), // "LXQtTaskBar"
QT_MOC_LITERAL(1, 12, 23), // "buttonRotationRefreshed"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 10), // "autoRotate"
QT_MOC_LITERAL(4, 48, 20), // "ILXQtPanel::Position"
QT_MOC_LITERAL(5, 69, 8), // "position"
QT_MOC_LITERAL(6, 78, 20), // "buttonStyleRefreshed"
QT_MOC_LITERAL(7, 99, 19), // "Qt::ToolButtonStyle"
QT_MOC_LITERAL(8, 119, 11), // "buttonStyle"
QT_MOC_LITERAL(9, 131, 19), // "refreshIconGeometry"
QT_MOC_LITERAL(10, 151, 22), // "showOnlySettingChanged"
QT_MOC_LITERAL(11, 174, 18), // "iconByClassChanged"
QT_MOC_LITERAL(12, 193, 10), // "popupShown"
QT_MOC_LITERAL(13, 204, 14), // "LXQtTaskGroup*"
QT_MOC_LITERAL(14, 219, 6), // "sender"
QT_MOC_LITERAL(15, 226, 15), // "settingsChanged"
QT_MOC_LITERAL(16, 242, 15), // "refreshTaskList"
QT_MOC_LITERAL(17, 258, 21), // "refreshButtonRotation"
QT_MOC_LITERAL(18, 280, 28), // "refreshPlaceholderVisibility"
QT_MOC_LITERAL(19, 309, 20), // "groupBecomeEmptySlot"
QT_MOC_LITERAL(20, 330, 15), // "onWindowChanged"
QT_MOC_LITERAL(21, 346, 3), // "WId"
QT_MOC_LITERAL(22, 350, 6), // "window"
QT_MOC_LITERAL(23, 357, 15), // "NET::Properties"
QT_MOC_LITERAL(24, 373, 4), // "prop"
QT_MOC_LITERAL(25, 378, 16), // "NET::Properties2"
QT_MOC_LITERAL(26, 395, 5), // "prop2"
QT_MOC_LITERAL(27, 401, 13), // "onWindowAdded"
QT_MOC_LITERAL(28, 415, 15), // "onWindowRemoved"
QT_MOC_LITERAL(29, 431, 17), // "registerShortcuts"
QT_MOC_LITERAL(30, 449, 18), // "shortcutRegistered"
QT_MOC_LITERAL(31, 468, 12), // "activateTask"
QT_MOC_LITERAL(32, 481, 3) // "pos"

    },
    "LXQtTaskBar\0buttonRotationRefreshed\0"
    "\0autoRotate\0ILXQtPanel::Position\0"
    "position\0buttonStyleRefreshed\0"
    "Qt::ToolButtonStyle\0buttonStyle\0"
    "refreshIconGeometry\0showOnlySettingChanged\0"
    "iconByClassChanged\0popupShown\0"
    "LXQtTaskGroup*\0sender\0settingsChanged\0"
    "refreshTaskList\0refreshButtonRotation\0"
    "refreshPlaceholderVisibility\0"
    "groupBecomeEmptySlot\0onWindowChanged\0"
    "WId\0window\0NET::Properties\0prop\0"
    "NET::Properties2\0prop2\0onWindowAdded\0"
    "onWindowRemoved\0registerShortcuts\0"
    "shortcutRegistered\0activateTask\0pos"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_LXQtTaskBar[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      17,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       6,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   99,    2, 0x06 /* Public */,
       6,    1,  104,    2, 0x06 /* Public */,
       9,    0,  107,    2, 0x06 /* Public */,
      10,    0,  108,    2, 0x06 /* Public */,
      11,    0,  109,    2, 0x06 /* Public */,
      12,    1,  110,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      15,    0,  113,    2, 0x0a /* Public */,
      16,    0,  114,    2, 0x08 /* Private */,
      17,    0,  115,    2, 0x08 /* Private */,
      18,    0,  116,    2, 0x08 /* Private */,
      19,    0,  117,    2, 0x08 /* Private */,
      20,    3,  118,    2, 0x08 /* Private */,
      27,    1,  125,    2, 0x08 /* Private */,
      28,    1,  128,    2, 0x08 /* Private */,
      29,    0,  131,    2, 0x08 /* Private */,
      30,    0,  132,    2, 0x08 /* Private */,
      31,    1,  133,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool, 0x80000000 | 4,    3,    5,
    QMetaType::Void, 0x80000000 | 7,    8,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 13,   14,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 21, 0x80000000 | 23, 0x80000000 | 25,   22,   24,   26,
    QMetaType::Void, 0x80000000 | 21,   22,
    QMetaType::Void, 0x80000000 | 21,   22,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   32,

       0        // eod
};

void LXQtTaskBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        LXQtTaskBar *_t = static_cast<LXQtTaskBar *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->buttonRotationRefreshed((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< ILXQtPanel::Position(*)>(_a[2]))); break;
        case 1: _t->buttonStyleRefreshed((*reinterpret_cast< Qt::ToolButtonStyle(*)>(_a[1]))); break;
        case 2: _t->refreshIconGeometry(); break;
        case 3: _t->showOnlySettingChanged(); break;
        case 4: _t->iconByClassChanged(); break;
        case 5: _t->popupShown((*reinterpret_cast< LXQtTaskGroup*(*)>(_a[1]))); break;
        case 6: _t->settingsChanged(); break;
        case 7: _t->refreshTaskList(); break;
        case 8: _t->refreshButtonRotation(); break;
        case 9: _t->refreshPlaceholderVisibility(); break;
        case 10: _t->groupBecomeEmptySlot(); break;
        case 11: _t->onWindowChanged((*reinterpret_cast< WId(*)>(_a[1])),(*reinterpret_cast< NET::Properties(*)>(_a[2])),(*reinterpret_cast< NET::Properties2(*)>(_a[3]))); break;
        case 12: _t->onWindowAdded((*reinterpret_cast< WId(*)>(_a[1]))); break;
        case 13: _t->onWindowRemoved((*reinterpret_cast< WId(*)>(_a[1]))); break;
        case 14: _t->registerShortcuts(); break;
        case 15: _t->shortcutRegistered(); break;
        case 16: _t->activateTask((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< LXQtTaskGroup* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (LXQtTaskBar::*_t)(bool , ILXQtPanel::Position );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&LXQtTaskBar::buttonRotationRefreshed)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (LXQtTaskBar::*_t)(Qt::ToolButtonStyle );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&LXQtTaskBar::buttonStyleRefreshed)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (LXQtTaskBar::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&LXQtTaskBar::refreshIconGeometry)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (LXQtTaskBar::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&LXQtTaskBar::showOnlySettingChanged)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (LXQtTaskBar::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&LXQtTaskBar::iconByClassChanged)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (LXQtTaskBar::*_t)(LXQtTaskGroup * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&LXQtTaskBar::popupShown)) {
                *result = 5;
                return;
            }
        }
    }
}

const QMetaObject LXQtTaskBar::staticMetaObject = {
    { &QFrame::staticMetaObject, qt_meta_stringdata_LXQtTaskBar.data,
      qt_meta_data_LXQtTaskBar,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *LXQtTaskBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LXQtTaskBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_LXQtTaskBar.stringdata0))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int LXQtTaskBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void LXQtTaskBar::buttonRotationRefreshed(bool _t1, ILXQtPanel::Position _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void LXQtTaskBar::buttonStyleRefreshed(Qt::ToolButtonStyle _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void LXQtTaskBar::refreshIconGeometry()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void LXQtTaskBar::showOnlySettingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void LXQtTaskBar::iconByClassChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void LXQtTaskBar::popupShown(LXQtTaskGroup * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
