/********************************************************************************
** Form generated from reading UI file 'lxqtvolumeconfiguration.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LXQTVOLUMECONFIGURATION_H
#define UI_LXQTVOLUMECONFIGURATION_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_LXQtVolumeConfiguration
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_2;
    QRadioButton *alsaRadioButton;
    QRadioButton *pulseAudioRadioButton;
    QRadioButton *ossRadioButton;
    QComboBox *devAddedCombo;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_3;
    QCheckBox *muteOnMiddleClickCheckBox;
    QCheckBox *showOnClickCheckBox;
    QCheckBox *ignoreMaxVolumeCheckBox;
    QCheckBox *allwaysShowNotificationsCheckBox;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QSpinBox *stepSpinBox;
    QGroupBox *groupBox_3;
    QVBoxLayout *verticalLayout_4;
    QLineEdit *mixerLineEdit;
    QDialogButtonBox *buttons;

    void setupUi(QDialog *LXQtVolumeConfiguration)
    {
        if (LXQtVolumeConfiguration->objectName().isEmpty())
            LXQtVolumeConfiguration->setObjectName(QStringLiteral("LXQtVolumeConfiguration"));
        LXQtVolumeConfiguration->resize(306, 407);
        verticalLayout = new QVBoxLayout(LXQtVolumeConfiguration);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        groupBox = new QGroupBox(LXQtVolumeConfiguration);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        verticalLayout_2 = new QVBoxLayout(groupBox);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        alsaRadioButton = new QRadioButton(groupBox);
        alsaRadioButton->setObjectName(QStringLiteral("alsaRadioButton"));

        horizontalLayout_2->addWidget(alsaRadioButton);

        pulseAudioRadioButton = new QRadioButton(groupBox);
        pulseAudioRadioButton->setObjectName(QStringLiteral("pulseAudioRadioButton"));

        horizontalLayout_2->addWidget(pulseAudioRadioButton);

        ossRadioButton = new QRadioButton(groupBox);
        ossRadioButton->setObjectName(QStringLiteral("ossRadioButton"));

        horizontalLayout_2->addWidget(ossRadioButton);


        verticalLayout_2->addLayout(horizontalLayout_2);

        devAddedCombo = new QComboBox(groupBox);
        devAddedCombo->setObjectName(QStringLiteral("devAddedCombo"));

        verticalLayout_2->addWidget(devAddedCombo);


        verticalLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(LXQtVolumeConfiguration);
        groupBox_2->setObjectName(QStringLiteral("groupBox_2"));
        verticalLayout_3 = new QVBoxLayout(groupBox_2);
        verticalLayout_3->setObjectName(QStringLiteral("verticalLayout_3"));
        muteOnMiddleClickCheckBox = new QCheckBox(groupBox_2);
        muteOnMiddleClickCheckBox->setObjectName(QStringLiteral("muteOnMiddleClickCheckBox"));

        verticalLayout_3->addWidget(muteOnMiddleClickCheckBox);

        showOnClickCheckBox = new QCheckBox(groupBox_2);
        showOnClickCheckBox->setObjectName(QStringLiteral("showOnClickCheckBox"));

        verticalLayout_3->addWidget(showOnClickCheckBox);

        ignoreMaxVolumeCheckBox = new QCheckBox(groupBox_2);
        ignoreMaxVolumeCheckBox->setObjectName(QStringLiteral("ignoreMaxVolumeCheckBox"));

        verticalLayout_3->addWidget(ignoreMaxVolumeCheckBox);

        allwaysShowNotificationsCheckBox = new QCheckBox(groupBox_2);
        allwaysShowNotificationsCheckBox->setObjectName(QStringLiteral("allwaysShowNotificationsCheckBox"));

        verticalLayout_3->addWidget(allwaysShowNotificationsCheckBox);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        label = new QLabel(groupBox_2);
        label->setObjectName(QStringLiteral("label"));
        QSizePolicy sizePolicy(QSizePolicy::Maximum, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(label);

        stepSpinBox = new QSpinBox(groupBox_2);
        stepSpinBox->setObjectName(QStringLiteral("stepSpinBox"));
        stepSpinBox->setMinimum(1);

        horizontalLayout->addWidget(stepSpinBox);


        verticalLayout_3->addLayout(horizontalLayout);


        verticalLayout->addWidget(groupBox_2);

        groupBox_3 = new QGroupBox(LXQtVolumeConfiguration);
        groupBox_3->setObjectName(QStringLiteral("groupBox_3"));
        verticalLayout_4 = new QVBoxLayout(groupBox_3);
        verticalLayout_4->setObjectName(QStringLiteral("verticalLayout_4"));
        mixerLineEdit = new QLineEdit(groupBox_3);
        mixerLineEdit->setObjectName(QStringLiteral("mixerLineEdit"));

        verticalLayout_4->addWidget(mixerLineEdit);


        verticalLayout->addWidget(groupBox_3);

        buttons = new QDialogButtonBox(LXQtVolumeConfiguration);
        buttons->setObjectName(QStringLiteral("buttons"));
        buttons->setOrientation(Qt::Horizontal);
        buttons->setStandardButtons(QDialogButtonBox::Close|QDialogButtonBox::Reset);

        verticalLayout->addWidget(buttons);


        retranslateUi(LXQtVolumeConfiguration);
        QObject::connect(buttons, SIGNAL(accepted()), LXQtVolumeConfiguration, SLOT(accept()));
        QObject::connect(buttons, SIGNAL(rejected()), LXQtVolumeConfiguration, SLOT(reject()));

        QMetaObject::connectSlotsByName(LXQtVolumeConfiguration);
    } // setupUi

    void retranslateUi(QDialog *LXQtVolumeConfiguration)
    {
        LXQtVolumeConfiguration->setWindowTitle(QApplication::translate("LXQtVolumeConfiguration", "Volume Control Settings", Q_NULLPTR));
        groupBox->setTitle(QApplication::translate("LXQtVolumeConfiguration", "Device to control", Q_NULLPTR));
        alsaRadioButton->setText(QApplication::translate("LXQtVolumeConfiguration", "Alsa", Q_NULLPTR));
        pulseAudioRadioButton->setText(QApplication::translate("LXQtVolumeConfiguration", "PulseAudio", Q_NULLPTR));
        ossRadioButton->setText(QApplication::translate("LXQtVolumeConfiguration", "OSS", Q_NULLPTR));
        groupBox_2->setTitle(QApplication::translate("LXQtVolumeConfiguration", "Behavior", Q_NULLPTR));
        muteOnMiddleClickCheckBox->setText(QApplication::translate("LXQtVolumeConfiguration", "Mute on middle click", Q_NULLPTR));
        showOnClickCheckBox->setText(QApplication::translate("LXQtVolumeConfiguration", "Show on mouse click", Q_NULLPTR));
        ignoreMaxVolumeCheckBox->setText(QApplication::translate("LXQtVolumeConfiguration", "Allow volume beyond 100% (0dB)", Q_NULLPTR));
        allwaysShowNotificationsCheckBox->setText(QApplication::translate("LXQtVolumeConfiguration", "Always notify about volume changes", Q_NULLPTR));
        label->setText(QApplication::translate("LXQtVolumeConfiguration", "Volume adjust step", Q_NULLPTR));
        groupBox_3->setTitle(QApplication::translate("LXQtVolumeConfiguration", "External Mixer", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class LXQtVolumeConfiguration: public Ui_LXQtVolumeConfiguration {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LXQTVOLUMECONFIGURATION_H
