/********************************************************************************
** Form generated from reading UI file 'kbdstateconfig.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KBDSTATECONFIG_H
#define UI_KBDSTATECONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_KbdStateConfig
{
public:
    QVBoxLayout *verticalLayout_3;
    QGroupBox *leds;
    QVBoxLayout *verticalLayout;
    QCheckBox *showCaps;
    QCheckBox *showNum;
    QCheckBox *showScroll;
    QGroupBox *showLayout;
    QVBoxLayout *verticalLayout_2;
    QLabel *policyLabel;
    QRadioButton *switchGlobal;
    QRadioButton *switchWindow;
    QRadioButton *switchApplication;
    QPushButton *configureLayouts;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *btns;
    QButtonGroup *modes;

    void setupUi(QDialog *KbdStateConfig)
    {
        if (KbdStateConfig->objectName().isEmpty())
            KbdStateConfig->setObjectName(QStringLiteral("KbdStateConfig"));
        KbdStateConfig->resize(249, 354);
        verticalLayout_3 = new QVBoxLayout(KbdStateConfig);
        verticalLayout_3->setObjectName(QStringLiteral("verticalLayout_3"));
        leds = new QGroupBox(KbdStateConfig);
        leds->setObjectName(QStringLiteral("leds"));
        verticalLayout = new QVBoxLayout(leds);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        showCaps = new QCheckBox(leds);
        showCaps->setObjectName(QStringLiteral("showCaps"));

        verticalLayout->addWidget(showCaps);

        showNum = new QCheckBox(leds);
        showNum->setObjectName(QStringLiteral("showNum"));

        verticalLayout->addWidget(showNum);

        showScroll = new QCheckBox(leds);
        showScroll->setObjectName(QStringLiteral("showScroll"));

        verticalLayout->addWidget(showScroll);


        verticalLayout_3->addWidget(leds);

        showLayout = new QGroupBox(KbdStateConfig);
        showLayout->setObjectName(QStringLiteral("showLayout"));
        showLayout->setCheckable(true);
        showLayout->setChecked(false);
        verticalLayout_2 = new QVBoxLayout(showLayout);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        policyLabel = new QLabel(showLayout);
        policyLabel->setObjectName(QStringLiteral("policyLabel"));

        verticalLayout_2->addWidget(policyLabel);

        switchGlobal = new QRadioButton(showLayout);
        modes = new QButtonGroup(KbdStateConfig);
        modes->setObjectName(QStringLiteral("modes"));
        modes->addButton(switchGlobal);
        switchGlobal->setObjectName(QStringLiteral("switchGlobal"));

        verticalLayout_2->addWidget(switchGlobal);

        switchWindow = new QRadioButton(showLayout);
        modes->addButton(switchWindow);
        switchWindow->setObjectName(QStringLiteral("switchWindow"));

        verticalLayout_2->addWidget(switchWindow);

        switchApplication = new QRadioButton(showLayout);
        modes->addButton(switchApplication);
        switchApplication->setObjectName(QStringLiteral("switchApplication"));

        verticalLayout_2->addWidget(switchApplication);


        verticalLayout_3->addWidget(showLayout);

        configureLayouts = new QPushButton(KbdStateConfig);
        configureLayouts->setObjectName(QStringLiteral("configureLayouts"));

        verticalLayout_3->addWidget(configureLayouts);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);

        btns = new QDialogButtonBox(KbdStateConfig);
        btns->setObjectName(QStringLiteral("btns"));
        btns->setOrientation(Qt::Horizontal);
        btns->setStandardButtons(QDialogButtonBox::Close|QDialogButtonBox::Reset);

        verticalLayout_3->addWidget(btns);


        retranslateUi(KbdStateConfig);
        QObject::connect(btns, SIGNAL(accepted()), KbdStateConfig, SLOT(accept()));
        QObject::connect(btns, SIGNAL(rejected()), KbdStateConfig, SLOT(reject()));

        QMetaObject::connectSlotsByName(KbdStateConfig);
    } // setupUi

    void retranslateUi(QDialog *KbdStateConfig)
    {
        KbdStateConfig->setWindowTitle(QApplication::translate("KbdStateConfig", "Keyboard state settings", Q_NULLPTR));
        leds->setTitle(QApplication::translate("KbdStateConfig", "Lock Indicators", Q_NULLPTR));
        showCaps->setText(QApplication::translate("KbdStateConfig", "Show Caps Lock", Q_NULLPTR));
        showNum->setText(QApplication::translate("KbdStateConfig", "Show Num Lock", Q_NULLPTR));
        showScroll->setText(QApplication::translate("KbdStateConfig", "Show Scroll Lock", Q_NULLPTR));
        showLayout->setTitle(QApplication::translate("KbdStateConfig", "Keyboard Layout Indicator", Q_NULLPTR));
        policyLabel->setText(QApplication::translate("KbdStateConfig", "Switching policy", Q_NULLPTR));
        switchGlobal->setText(QApplication::translate("KbdStateConfig", "Global", Q_NULLPTR));
        switchWindow->setText(QApplication::translate("KbdStateConfig", "Window", Q_NULLPTR));
        switchApplication->setText(QApplication::translate("KbdStateConfig", "Application", Q_NULLPTR));
        configureLayouts->setText(QApplication::translate("KbdStateConfig", "Configure layouts", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class KbdStateConfig: public Ui_KbdStateConfig {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_KBDSTATECONFIG_H
